/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 480 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 963 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_DECIMAL:
        p->type = FIELD_TYPE_DECIMAL;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
      if (rc > name_sz) {
        name_sz = rc;
        p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
        if (p == NULL) {
          pParse->is_aborted = true;
          return;
        }
        p->u.zToken = (char *)&p[1];
        sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
  }
#line 1270 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1344 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1365 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1567 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1783 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 263 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 285
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 77
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  bool yy9;
  struct Expr * yy71;
  Expr* yy130;
  struct LimitVal yy132;
  ExprList * yy142;
  SrcList* yy147;
  enum trim_side_mask yy157;
  struct SrcList * yy176;
  struct type_def yy194;
  IdList* yy200;
  struct alter_args yy242;
  ExprSpan yy358;
  struct ExprList * yy359;
  struct Token yy375;
  int yy420;
  ExprList* yy442;
  Select* yy491;
  struct TrigEvent yy498;
  With* yy523;
  TriggerStep* yy524;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             459
#define YYNRULE              334
#define YY_MAX_SHIFT         458
#define YY_MIN_SHIFTREDUCE   688
#define YY_MAX_SHIFTREDUCE   1021
#define YY_MIN_REDUCE        1022
#define YY_MAX_REDUCE        1355
#define YY_ERROR_ACTION      1356
#define YY_ACCEPT_ACTION     1357
#define YY_NO_ACTION         1358
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1795)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    58,  974,   69,   69,   69,   69,   68,   68,   67,   67,
 /*    10 */    67,   66,  332,  332,   23,   23, 1020,   55,   56,   23,
 /*    20 */   705, 1001,  309,  140,   57,   11,  736, 1001,  324,  839,
 /*    30 */   334,  719,  334,  177,  393,  305,  442,    3,  291,  737,
 /*    40 */   308,  839,  998,  333,  333,  334,  705,   67,   67,   67,
 /*    50 */    66,  332,  986,   23,  800,  457,  457,  772,  148,  301,
 /*    60 */   325,  834,  431,  145,  207,  207,   68,   68,   67,   67,
 /*    70 */    67,   66,  332,  834,   23,  385,  406,   65,   63,  206,
 /*    80 */   689,  336,  968,  969,  970,  971,  972,  973,  975,  976,
 /*    90 */   977,  978,  979,  293,  982,  983,  984,  984,  985,  759,
 /*   100 */   785,  836,   80,  838,  838,  840,  841,  842,  843,  844,
 /*   110 */   954,   65,   63,  206,  953,  838,  838,  840,  841,  842,
 /*   120 */   843,  844,  845,  312,  312,  450,   58,   10,  452,  445,
 /*   130 */   865,  866,  867, 1015,   22, 1001,  309,  327,  440,  452,
 /*   140 */   347, 1001,  166,   55,   56,  719,   93,   93,  706,  706,
 /*   150 */    57,   11,  189,  188,  139,  997,  304,  116,  116,  705,
 /*   160 */   323,  273,  442,    3, 1239,  148,  955,  839,  408,  333,
 /*   170 */   333,  132,    7,  828,  955, 1333, 1010,  148, 1010, 1333,
 /*   180 */   421,   66,  332,  132,   23,  785,  192,  204,  431,  916,
 /*   190 */   254,  357,  922,  202,  426,  422,   58,  786,  954,  834,
 /*   200 */   832,  828,  425,   27,  799,  444,  246,  403,  247,  184,
 /*   210 */   280,  951,  452,   55,   56, 1333,  444,  376,  265,  367,
 /*   220 */    57,   11,  314,  273,  266,  817,  239,  836,  246,  403,
 /*   230 */   116,  116,  442,    3,  148,  148,  704,  839,  945,  333,
 /*   240 */   333,  838,  838,  840,  841,  842,  843,  844,  845,  312,
 /*   250 */   312,  450,  266,   10,  946,  445,  195,  786,  431, 1015,
 /*   260 */    22,   65,   63,  206,  947,  430,  361,  426,  404,  834,
 /*   270 */   722,   71,   71,   71,   71,   64,   69,   69,   69,   69,
 /*   280 */    68,   68,   67,   67,   67,   66,  332,  449,   23,  444,
 /*   290 */   709, 1297, 1297,   71,   71,   71,   71,  836,   69,   69,
 /*   300 */    69,   69,   68,   68,   67,   67,   67,   66,  332,  224,
 /*   310 */    23,  838,  838,  840,  841,  842,  843,  844,  845,  312,
 /*   320 */   312,  450,  918,   10,  704,  445, 1357,  458,    1, 1015,
 /*   330 */    22,   72,   73,  310,  331,  880,  880,  890,  893,   70,
 /*   340 */    70,   71,   71,   71,   71,   58,   69,   69,   69,   69,
 /*   350 */    68,   68,   67,   67,   67,   66,  332,  208,   23,  452,
 /*   360 */   370,  452,   55,   56,  773,  452,   65,   63,  206,   57,
 /*   370 */    11,  706,  706,  370, 1010,  449, 1010,   40,   40,  116,
 /*   380 */   116,  442,    3,   88,   88,   54,  839,   52,  333,  333,
 /*   390 */   456,  313,  693,  455,  249,  302, 1011, 1011,  699,  213,
 /*   400 */   337,  958,  339,  148,  376, 1055,  400,  431,  957,  132,
 /*   410 */   785,  327,   42,  140,  342,   58,  426,  409,  834, 1040,
 /*   420 */   401,  245,  996,  181,  239,  305,  712,  802,  219,  452,
 /*   430 */   308,   26,   55,   56,  323,  996,  444,  711,  444,   57,
 /*   440 */    11,  225,  444,  391,  389,  395,  836,  118,  118,  352,
 /*   450 */   253,  442,    3,  307, 1012,  788,  839,  388,  333,  333,
 /*   460 */   838,  838,  840,  841,  842,  843,  844,  845,  312,  312,
 /*   470 */   450,  925,   10,  924,  445,  353,  212,  431, 1015,   22,
 /*   480 */   376,  360,  247,  184,  280,   58,  207,  207,  834,  722,
 /*   490 */    65,   63,  206,  742,  187,  186,  264,  273,  406,  801,
 /*   500 */   419,  452,   55,   56,  217,  452,  444, 1011, 1011,   57,
 /*   510 */    11,  348,  344,  355,   76,   47,  836,  199,  839,  116,
 /*   520 */   116,  442,    3,  116,  116,  945,  839,  743,  333,  333,
 /*   530 */   838,  838,  840,  841,  842,  843,  844,  845,  312,  312,
 /*   540 */   450,  946,   10,  149,  445,  275,  274,  431, 1015,   22,
 /*   550 */   834,  947,  752,  144,  751,  751,  426,  420,  834,  753,
 /*   560 */   426,  443,   65,   63,  206, 1012,  787,  396,  716,  395,
 /*   570 */   234,  345,  227,  803,  804,  706,  706,  169,  444,  275,
 /*   580 */   274,  338,  444,  706,  706,  920,  836,   38,  881,  881,
 /*   590 */   891,  894,  838,  838,  840,  841,  842,  843,  844,  728,
 /*   600 */   838,  838,  840,  841,  842,  843,  844,  845,  312,  312,
 /*   610 */   450,  247,   10,  718,  445,  275,  274,  779, 1015,   22,
 /*   620 */    72,   73,  310,  331,  880,  880,  890,  893,   70,   70,
 /*   630 */    71,   71,   71,   71,  729,   69,   69,   69,   69,   68,
 /*   640 */    68,   67,   67,   67,   66,  332,  215,   23,   72,   73,
 /*   650 */   310,  331,  880,  880,  890,  893,   70,   70,   71,   71,
 /*   660 */    71,   71,  238,   69,   69,   69,   69,   68,   68,   67,
 /*   670 */    67,   67,   66,  332,  148,   23,  362,  928,   72,   73,
 /*   680 */   310,  331,  880,  880,  890,  893,   70,   70,   71,   71,
 /*   690 */    71,   71,   43,   69,   69,   69,   69,   68,   68,   67,
 /*   700 */    67,   67,   66,  332, 1010,   23, 1010,  354,  167,  942,
 /*   710 */   928,   74,  132,  452,  706,  706,  429,  452,  706,  706,
 /*   720 */   452,  398,  452,  774,  452,  749,  749,   82,  805,  806,
 /*   730 */   832,   40,   40,  706,  706,   40,   40,  368,   94,   94,
 /*   740 */    77,   77,   40,   40,    2,  319,  259,  706,  706,  321,
 /*   750 */   706,  706,  825,  322,  239,  132,  416,  413,  722,  377,
 /*   760 */   402,  194,  764,  764,   72,   73,  310,  331,  880,  880,
 /*   770 */   890,  893,   70,   70,   71,   71,   71,   71,  832,   69,
 /*   780 */    69,   69,   69,   68,   68,   67,   67,   67,   66,  332,
 /*   790 */   444,   23,  424,  423,  444,  769,  316,  444,  365,  444,
 /*   800 */   768,  444,  785,  258,  956,  730,  731,  732,  785,  282,
 /*   810 */    72,   73,  310,  331,  880,  880,  890,  893,   70,   70,
 /*   820 */    71,   71,   71,   71,  172,   69,   69,   69,   69,   68,
 /*   830 */    68,   67,   67,   67,   66,  332,  291,   23,  786,  381,
 /*   840 */   378,  746,  220,  761,  317,  197,  785,  785,  221,  746,
 /*   850 */   717,  257,  846,  846,  406,  256,   72,   73,  310,  331,
 /*   860 */   880,  880,  890,  893,   70,   70,   71,   71,   71,   71,
 /*   870 */   452,   69,   69,   69,   69,   68,   68,   67,   67,   67,
 /*   880 */    66,  332,  940,   23,  410,  132,  948,  917,  113,  113,
 /*   890 */   372,  785,  785,  205,  204,  785,  710,  195,  786,   12,
 /*   900 */   916,  374,   72,   73,  310,  331,  880,  880,  890,  893,
 /*   910 */    70,   70,   71,   71,   71,   71,  832,   69,   69,   69,
 /*   920 */    69,   68,   68,   67,   67,   67,   66,  332,  411,   23,
 /*   930 */   847,  755,  754,  320,  942,  261,  436,  132,  805,  806,
 /*   940 */   758,  916,  871,  132,  837,  375,  290,  444,   72,   73,
 /*   950 */   310,  331,  880,  880,  890,  893,   70,   70,   71,   71,
 /*   960 */    71,   71,  368,   69,   69,   69,   69,   68,   68,   67,
 /*   970 */    67,   67,   66,  332,  330,   23,  284,  433,  437,   81,
 /*   980 */   132,  132,  318,  441,  366,  769,  132,  340,  833,  830,
 /*   990 */   768,  241,  286,  237,   72,   73,  310,  331,  880,  880,
 /*  1000 */   890,  893,   70,   70,   71,   71,   71,   71,  193,   69,
 /*  1010 */    69,   69,   69,   68,   68,   67,   67,   67,   66,  332,
 /*  1020 */   289,   23,   72,   73,  310,  331,  880,  880,  890,  893,
 /*  1030 */    70,   70,   71,   71,   71,   71,  174,   69,   69,   69,
 /*  1040 */    69,   68,   68,   67,   67,   67,   66,  332,  832,   23,
 /*  1050 */    72,   73,  310,  331,  880,  880,  890,  893,   70,   70,
 /*  1060 */    71,   71,   71,   71,  252,   69,   69,   69,   69,   68,
 /*  1070 */    68,   67,   67,   67,   66,  332,  962,   23,   72,   73,
 /*  1080 */   310,  331,  880,  880,  890,  893,   70,   70,   71,   71,
 /*  1090 */    71,   71,  960,   69,   69,   69,   69,   68,   68,   67,
 /*  1100 */    67,   67,   66,  332,  407,   23,  369,  371,  910, 1009,
 /*  1110 */   237,  237,   42,  386,  329,  952,  745,  241,  950,   45,
 /*  1120 */    42,  961,   25,   25,   48,   72,   73,  310,  331,  880,
 /*  1130 */   880,  890,  893,   70,   70,   71,   71,   71,   71,  451,
 /*  1140 */    69,   69,   69,   69,   68,   68,   67,   67,   67,   66,
 /*  1150 */   332,  349,   23,   72,   73,  310,  331,  880,  880,  890,
 /*  1160 */   893,   70,   70,   71,   71,   71,   71,  182,   69,   69,
 /*  1170 */    69,   69,   68,   68,   67,   67,   67,   66,  332,  744,
 /*  1180 */    23,  444,  315,   34,  148,  452,  720,  720,   50,  190,
 /*  1190 */   191,  735,  734,  279,  766,  795,  914,  350,   49,  237,
 /*  1200 */   241,  993,  351,   90,   90,   14,  278,  820,  828,  848,
 /*  1210 */   848,  356,  884,  452,  255,  358,   53,  198,  939,  263,
 /*  1220 */   937,  373,  936,  379,  380,  265,  367,   59,  268,  698,
 /*  1230 */   272,   84,   84,   72,   73,  310,  331,  880,  880,  890,
 /*  1240 */   893,   70,   70,   71,   71,   71,   71,  277,   69,   69,
 /*  1250 */    69,   69,   68,   68,   67,   67,   67,   66,  332,  266,
 /*  1260 */    23,  715,  444,  793,   72,   73,  310,  331,  880,  880,
 /*  1270 */   890,  893,   70,   70,   71,   71,   71,   71,   60,   69,
 /*  1280 */    69,   69,   69,   68,   68,   67,   67,   67,   66,  332,
 /*  1290 */   444,   23,   72,   62,  310,  331,  880,  880,  890,  893,
 /*  1300 */    70,   70,   71,   71,   71,   71,  831,   69,   69,   69,
 /*  1310 */    69,   68,   68,   67,   67,   67,   66,  332,  288,   23,
 /*  1320 */   775,  432,  915,  292,    9,  298,  141,  183,  707,  133,
 /*  1330 */   311,  251,  153,   73,  310,  331,  880,  880,  890,  893,
 /*  1340 */    70,   70,   71,   71,   71,   71,  270,   69,   69,   69,
 /*  1350 */    69,   68,   68,   67,   67,   67,   66,  332,  696,   23,
 /*  1360 */   310,  331,  880,  880,  890,  893,   70,   70,   71,   71,
 /*  1370 */    71,   71,  695,   69,   69,   69,   69,   68,   68,   67,
 /*  1380 */    67,   67,   66,  332,  697,   23,  452,  173,  911,  164,
 /*  1390 */   452,  155,  142,   38,  816,  452,  359,   29,  452,  157,
 /*  1400 */   222,  159,  160,  269,   96,   96,  923,  452,   97,   97,
 /*  1410 */   260,  364,  384,   98,   98,  452,  116,  116,  452,  223,
 /*  1420 */   941,  452,  175,  452,  168,   99,   99,  452,  827,  382,
 /*  1430 */   452,  230,  452,  116,  116,  231,  116,  116,  452,  116,
 /*  1440 */   116,  100,  100,  232,  134,   78,   78,  452,   85,   85,
 /*  1450 */    87,   87,  326,  426,  446,  262,  101,  101,  271,  452,
 /*  1460 */   392,  452,  394,  444,  452,  102,  102,  444,  276,  452,
 /*  1470 */   426,  399,  444,  328,  740,  444,  414,  103,  103,   41,
 /*  1480 */    41,  725,  104,  104,  444,  726,  135,  105,  105,  397,
 /*  1490 */   739,  714,  444,  452,  713,  444,  412,  783,  444,  452,
 /*  1500 */   444,  452,  281,   37,  444,    8,  784,  444,   51,  444,
 /*  1510 */   782,  106,  106,  283,  285,  444,  452,   89,   89,  107,
 /*  1520 */   107,  452,  781,  435,  444,  452,  287,  439,  448,  452,
 /*  1530 */   898,  452,  981,  452,  108,  108,  444,  452,  444,  109,
 /*  1540 */   109,  444,  452,  110,  110,  452,  444,   91,   91,  111,
 /*  1550 */   111,  112,  112,  452,  240,   92,   92,   75,  765,  417,
 /*  1560 */   136,  136,  452,  137,  137,  452,  294,  452,  295,   39,
 /*  1570 */   444,  138,  138,  415,  454,  299,  444,  452,  444,  297,
 /*  1580 */   121,  121,  296,  114,  114,  115,  115,  994,  306,    4,
 /*  1590 */   300,  990,  248,  444,  250,   95,   95,  452,  444,  452,
 /*  1600 */    13,  691,  444,   79,  992,  452,  444,  452,  444,  452,
 /*  1610 */   444,  335,   15,  959,  444,  124,  124,  117,  117,  444,
 /*  1620 */    28,  209,  444,  125,  125,  123,  123,  131,  131,  452,
 /*  1630 */   444,  452,  150,  452,  341,  210,  343,  211,  452,  444,
 /*  1640 */   214,  452,  444,  452,  444,  452,  346,  130,  130,  129,
 /*  1650 */   129,  128,  128,  452,  444,  151,  126,  126,  921,  127,
 /*  1660 */   127,  120,  120,  122,  122,  216,  185,  218,  152,  452,
 /*  1670 */   826,  119,  119,  146,  444,  452,  444,  156,  154,  158,
 /*  1680 */   756,  926,  444,  237,  444,  161,  444,   83,   83, 1017,
 /*  1690 */   363,  162,  935,   86,   86,  165,  163,   30,   31,   32,
 /*  1700 */    33,  147,  938,  934,  226,  228,  444,   24,  444,   16,
 /*  1710 */   444,  229,  176,  701,  267,  444,  383,  278,  444,  233,
 /*  1720 */   444,  170,  444,  387,   17,   18,  390,  190,  738,  191,
 /*  1730 */   444,   35,  143,  235,  870,  868,  763,  896,   19,  200,
 /*  1740 */   767,    6,   36,  201,  203,  405,  444,  171,  236,   20,
 /*  1750 */    49,  794,  444,  789,   42,   21,   44,  909,  897,  418,
 /*  1760 */   895,  858,  854,   46,  944,  427,  943,  428,  900,  196,
 /*  1770 */   434,  966,  178,  244,  967,  179,  242,  438,  899,  180,
 /*  1780 */   853,  869,  243,    5,  885,  980,  447,  849,   61,  702,
 /*  1790 */   453,  303,  692,  688, 1321,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     7,   76,   20,   21,   22,   23,   24,   25,   26,   27,
 /*    10 */    28,   29,   30,   30,   32,   32,  192,   24,   25,   32,
 /*    20 */   196,  197,  198,  181,   31,   32,   58,  203,   86,   48,
 /*    30 */   188,  207,  190,  191,   66,  193,   43,   44,  181,   71,
 /*    40 */   198,   48,  192,   50,   51,  203,  196,   26,   27,   28,
 /*    50 */    29,   30,  127,   32,  202,  178,  179,  239,   46,  182,
 /*    60 */    92,   80,   69,  186,  223,  224,   24,   25,   26,   27,
 /*    70 */    28,   29,   30,   80,   32,    7,  235,  259,  260,  261,
 /*    80 */     1,    2,  157,  158,  159,  160,  161,  162,  163,  164,
 /*    90 */   165,  166,  167,  168,  169,  170,  171,  172,  173,  222,
 /*   100 */   181,  108,  225,  122,  123,  124,  125,  126,  127,  128,
 /*   110 */   195,  259,  260,  261,  181,  122,  123,  124,  125,  126,
 /*   120 */   127,  128,  129,  130,  131,  132,    7,  134,  181,  136,
 /*   130 */   137,  138,  139,  140,  141,  197,  198,    7,  281,  181,
 /*   140 */   221,  203,   44,   24,   25,  207,  199,  200,   50,   51,
 /*   150 */    31,   32,  275,  276,  277,  192,  279,  199,  200,  196,
 /*   160 */    30,   93,   43,   44,   45,   46,  207,   48,  222,   50,
 /*   170 */    51,  225,   44,   70,  215,   45,   48,   46,   50,   49,
 /*   180 */   222,   29,   30,  225,   32,  181,  240,  241,   69,  181,
 /*   190 */    87,   88,   61,   45,  236,  237,    7,   49,  283,   80,
 /*   200 */   181,   70,  255,  256,  202,  258,  103,  104,   78,   79,
 /*   210 */    80,  278,  181,   24,   25,   85,  258,  181,   87,   88,
 /*   220 */    31,   32,  214,   93,  121,  221,   98,  108,  103,  104,
 /*   230 */   199,  200,   43,   44,   46,   46,  195,   48,   36,   50,
 /*   240 */    51,  122,  123,  124,  125,  126,  127,  128,  129,  130,
 /*   250 */   131,  132,  121,  134,   52,  136,  108,  109,   69,  140,
 /*   260 */   141,  259,  260,  261,   62,   63,  247,  236,  237,   80,
 /*   270 */    85,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   280 */    24,   25,   26,   27,   28,   29,   30,  195,   32,  258,
 /*   290 */   199,  103,  104,   15,   16,   17,   18,  108,   20,   21,
 /*   300 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  273,
 /*   310 */    32,  122,  123,  124,  125,  126,  127,  128,  129,  130,
 /*   320 */   131,  132,  199,  134,  283,  136,  175,  176,  177,  140,
 /*   330 */   141,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   340 */    14,   15,   16,   17,   18,    7,   20,   21,   22,   23,
 /*   350 */    24,   25,   26,   27,   28,   29,   30,   44,   32,  181,
 /*   360 */   181,  181,   24,   25,   26,  181,  259,  260,  261,   31,
 /*   370 */    32,   50,   51,  181,   48,  283,   50,  199,  200,  199,
 /*   380 */   200,   43,   44,  199,  200,  142,   48,  144,   50,   51,
 /*   390 */    33,  213,   35,   36,   37,   38,   50,   51,   41,   78,
 /*   400 */    81,   82,   83,   46,  181,    1,  222,   69,   45,  225,
 /*   410 */   181,    7,   49,  181,   95,    7,  236,  237,   80,  106,
 /*   420 */   236,  228,  190,  191,   98,  193,  199,  196,  249,  181,
 /*   430 */   198,  238,   24,   25,   30,  203,  258,  199,  258,   31,
 /*   440 */    32,  249,  258,   81,   82,   83,  108,  199,  200,   92,
 /*   450 */   221,   43,   44,   96,  108,  109,   48,   95,   50,   51,
 /*   460 */   122,  123,  124,  125,  126,  127,  128,  129,  130,  131,
 /*   470 */   132,   55,  134,   57,  136,  118,  155,   69,  140,  141,
 /*   480 */   181,   65,   78,   79,   80,    7,  223,  224,   80,   85,
 /*   490 */   259,  260,  261,   60,   24,   25,  273,   93,  235,  196,
 /*   500 */   252,  181,   24,   25,  147,  181,  258,   50,   51,   31,
 /*   510 */    32,  154,  248,  250,   44,  107,  108,   49,   48,  199,
 /*   520 */   200,   43,   44,  199,  200,   36,   48,   94,   50,   51,
 /*   530 */   122,  123,  124,  125,  126,  127,  128,  129,  130,  131,
 /*   540 */   132,   52,  134,  206,  136,  208,  209,   69,  140,  141,
 /*   550 */    80,   62,   63,   54,  218,  219,  236,  237,   80,   70,
 /*   560 */   236,  237,  259,  260,  261,  108,  109,   81,   82,   83,
 /*   570 */    84,   72,  273,   74,   75,   50,   51,  206,  258,  208,
 /*   580 */   209,  280,  258,   50,   51,   45,  108,  119,    9,   10,
 /*   590 */    11,   12,  122,  123,  124,  125,  126,  127,  128,  210,
 /*   600 */   122,  123,  124,  125,  126,  127,  128,  129,  130,  131,
 /*   610 */   132,   78,  134,  206,  136,  208,  209,  242,  140,  141,
 /*   620 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   630 */    15,   16,   17,   18,  210,   20,   21,   22,   23,   24,
 /*   640 */    25,   26,   27,   28,   29,   30,  106,   32,    5,    6,
 /*   650 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   660 */    17,   18,  239,   20,   21,   22,   23,   24,   25,   26,
 /*   670 */    27,   28,   29,   30,   46,   32,   87,   88,    5,    6,
 /*   680 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   690 */    17,   18,   49,   20,   21,   22,   23,   24,   25,   26,
 /*   700 */    27,   28,   29,   30,   48,   32,   50,   79,   44,  222,
 /*   710 */   121,   68,  225,  181,   50,   51,  219,  181,   50,   51,
 /*   720 */   181,   26,  181,   26,  181,  218,  219,   44,  113,  114,
 /*   730 */   181,  199,  200,   50,   51,  199,  200,  250,  199,  200,
 /*   740 */   199,  200,  199,  200,   44,  213,   40,   50,   51,  213,
 /*   750 */    50,   51,  222,  212,   98,  225,  213,  246,   85,  272,
 /*   760 */    99,  246,  101,  102,    5,    6,    7,    8,    9,   10,
 /*   770 */    11,   12,   13,   14,   15,   16,   17,   18,  181,   20,
 /*   780 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   790 */   258,   32,  253,  254,  258,  100,  247,  258,  269,  258,
 /*   800 */   105,  258,  181,   97,   45,   89,   90,   91,  181,  239,
 /*   810 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   820 */    15,   16,   17,   18,  156,   20,   21,   22,   23,   24,
 /*   830 */    25,   26,   27,   28,   29,   30,  181,   32,   49,  265,
 /*   840 */   266,  207,  221,  224,  247,  268,  181,  181,  221,  215,
 /*   850 */    45,  145,   50,   51,  235,  149,    5,    6,    7,    8,
 /*   860 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   870 */   181,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   880 */    29,   30,  222,   32,    7,  225,  221,  221,  199,  200,
 /*   890 */   181,  181,  181,  240,  241,  181,   45,  108,  109,  227,
 /*   900 */   181,    7,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   910 */    13,   14,   15,   16,   17,   18,  181,   20,   21,   22,
 /*   920 */    23,   24,   25,   26,   27,   28,   29,   30,   51,   32,
 /*   930 */   128,  221,  221,  214,  222,  221,  281,  225,  113,  114,
 /*   940 */   222,  181,   45,  225,  181,   51,  257,  258,    5,    6,
 /*   950 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   960 */    17,   18,  250,   20,   21,   22,   23,   24,   25,   26,
 /*   970 */    27,   28,   29,   30,  214,   32,  239,  222,  222,  267,
 /*   980 */   225,  225,  247,  222,  272,  100,  225,   45,   45,   45,
 /*   990 */   105,   49,  239,   49,    5,    6,    7,    8,    9,   10,
 /*  1000 */    11,   12,   13,   14,   15,   16,   17,   18,  181,   20,
 /*  1010 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*  1020 */   181,   32,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  1030 */    13,   14,   15,   16,   17,   18,  226,   20,   21,   22,
 /*  1040 */    23,   24,   25,   26,   27,   28,   29,   30,  181,   32,
 /*  1050 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  1060 */    15,   16,   17,   18,  181,   20,   21,   22,   23,   24,
 /*  1070 */    25,   26,   27,   28,   29,   30,  181,   32,    5,    6,
 /*  1080 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  1090 */    17,   18,  181,   20,   21,   22,   23,   24,   25,   26,
 /*  1100 */    27,   28,   29,   30,  181,   32,   45,   45,   45,   49,
 /*  1110 */    49,   49,   49,   45,  247,  181,   45,   49,  181,  130,
 /*  1120 */    49,  181,  199,  200,  107,    5,    6,    7,    8,    9,
 /*  1130 */    10,   11,   12,   13,   14,   15,   16,   17,   18,    7,
 /*  1140 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1150 */    30,  181,   32,    5,    6,    7,    8,    9,   10,   11,
 /*  1160 */    12,   13,   14,   15,   16,   17,   18,  107,   20,   21,
 /*  1170 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   45,
 /*  1180 */    32,  258,  181,   49,   46,  181,   50,   51,  143,   87,
 /*  1190 */    88,   79,   80,   80,   45,   45,   45,  181,   49,   49,
 /*  1200 */    49,   45,  181,  199,  200,   49,   93,  230,   70,   50,
 /*  1210 */    51,  243,   80,  181,  243,  181,  143,  181,  230,  274,
 /*  1220 */   181,  274,  181,  181,  181,   87,   88,  107,  181,  181,
 /*  1230 */   181,  199,  200,    5,    6,    7,    8,    9,   10,   11,
 /*  1240 */    12,   13,   14,   15,   16,   17,   18,  181,   20,   21,
 /*  1250 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  121,
 /*  1260 */    32,  202,  258,  181,    5,    6,    7,    8,    9,   10,
 /*  1270 */    11,   12,   13,   14,   15,   16,   17,   18,  130,   20,
 /*  1280 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*  1290 */   258,   32,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  1300 */    13,   14,   15,   16,   17,   18,  181,   20,   21,   22,
 /*  1310 */    23,   24,   25,   26,   27,   28,   29,   30,  243,   32,
 /*  1320 */   181,  264,  181,  181,  227,  229,   98,  227,  181,  205,
 /*  1330 */     9,  204,  251,    6,    7,    8,    9,   10,   11,   12,
 /*  1340 */    13,   14,   15,   16,   17,   18,   40,   20,   21,   22,
 /*  1350 */    23,   24,   25,   26,   27,   28,   29,   30,  181,   32,
 /*  1360 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  1370 */    17,   18,  181,   20,   21,   22,   23,   24,   25,   26,
 /*  1380 */    27,   28,   29,   30,  181,   32,  181,   44,   82,   44,
 /*  1390 */   181,  217,    5,  119,  230,  181,   42,  142,  181,  220,
 /*  1400 */   220,  220,  220,   97,  199,  200,  271,  181,  199,  200,
 /*  1410 */   270,  151,   42,  199,  200,  181,  199,  200,  181,  187,
 /*  1420 */   230,  181,  251,  181,  217,  199,  200,  181,  217,  204,
 /*  1430 */   181,  187,  181,  199,  200,  187,  199,  200,  181,  199,
 /*  1440 */   200,  199,  200,  187,  205,  199,  200,  181,  199,  200,
 /*  1450 */   199,  200,   64,  236,  237,  149,  199,  200,  204,  181,
 /*  1460 */    86,  181,   86,  258,  181,  199,  200,  258,  204,  181,
 /*  1470 */   236,  237,  258,  236,  211,  258,  236,  199,  200,  199,
 /*  1480 */   200,  208,  199,  200,  258,  209,  205,  199,  200,   86,
 /*  1490 */   211,  201,  258,  181,  201,  258,  111,  245,  258,  181,
 /*  1500 */   258,  181,  244,   86,  258,   44,  245,  258,  142,  258,
 /*  1510 */   245,  199,  200,  244,  244,  258,  181,  199,  200,  199,
 /*  1520 */   200,  181,  245,  204,  258,  181,  244,  204,   44,  181,
 /*  1530 */   262,  181,  282,  181,  199,  200,  258,  181,  258,  199,
 /*  1540 */   200,  258,  181,  199,  200,  181,  258,  199,  200,  199,
 /*  1550 */   200,  199,  200,  181,  263,  199,  200,  117,  234,  112,
 /*  1560 */   199,  200,  181,  199,  200,  181,  233,  181,  232,  116,
 /*  1570 */   258,  199,  200,  115,   47,   46,  258,  181,  258,  230,
 /*  1580 */   199,  200,  231,  199,  200,  199,  200,  189,  184,   44,
 /*  1590 */   183,   37,  180,  258,  180,  199,  200,  181,  258,  181,
 /*  1600 */   194,    4,  258,  194,  185,  181,  258,  181,  258,  181,
 /*  1610 */   258,    3,   44,   67,  258,  199,  200,  199,  200,  258,
 /*  1620 */    44,   84,  258,  199,  200,  199,  200,  199,  200,  181,
 /*  1630 */   258,  181,   44,  181,   67,   78,   83,   39,  181,  258,
 /*  1640 */    78,  181,  258,  181,  258,  181,   96,  199,  200,  199,
 /*  1650 */   200,  199,  200,  181,  258,   40,  199,  200,   45,  199,
 /*  1660 */   200,  199,  200,  199,  200,   44,   14,  146,   40,  181,
 /*  1670 */   104,  199,  200,   92,  258,  181,  258,  107,  120,   86,
 /*  1680 */    43,  150,  258,   49,  258,  150,  258,  199,  200,  153,
 /*  1690 */   152,   86,    1,  199,  200,  120,  107,   14,   14,   14,
 /*  1700 */    14,   92,   51,    1,  110,  106,  258,  148,  258,   44,
 /*  1710 */   258,   86,   98,   43,  145,  258,    7,   93,  258,   84,
 /*  1720 */   258,   44,  258,   67,   44,   44,   67,   87,   53,   88,
 /*  1730 */   258,   44,   59,   67,   45,   45,  100,   45,   44,  106,
 /*  1740 */    45,   44,   49,   45,   45,   49,  258,   44,  110,  110,
 /*  1750 */    49,   51,  258,  109,   49,  110,   32,   45,   45,  133,
 /*  1760 */    45,   45,  135,   49,   45,   48,   45,   49,   61,   44,
 /*  1770 */    98,   45,   44,  106,   45,   44,   49,   98,   45,   44,
 /*  1780 */   133,   45,   44,   44,   80,   45,  128,   45,   44,   48,
 /*  1790 */    14,   39,   34,    1,    0,
};
#define YY_SHIFT_USE_DFLT (1795)
#define YY_SHIFT_COUNT    (458)
#define YY_SHIFT_MIN      (-75)
#define YY_SHIFT_MAX      (1794)
static const short yy_shift_ofst[] = {
 /*     0 */    79,  357,  119,  189,  533,   -7,  478,  478,  478,  478,
 /*    10 */   478,  478,  478,  404,  533,  478,  478,  478,  478,  478,
 /*    20 */   478,  478,  478,  478, 1138,  326,  338,  408,  478,  478,
 /*    30 */   478,  478,  478,  478,  478,  478,  478,  478,  478,  478,
 /*    40 */   615,  615,  478,  478,  478,  478,  478,  478,  478,  478,
 /*    50 */   478,  478,  478,  478,  478,  478,  478,  478,  478,  478,
 /*    60 */   478,  478,  478,  478,  478,  478,  478,  478,  478,  478,
 /*    70 */   478,  478,  478,  478,  478,  478,  478,  673,  673,  130,
 /*    80 */   103,  131,  188,  643,  759,  805,  851,  897,  943,  989,
 /*    90 */  1017, 1045, 1073, 1120, 1148, 1228, 1259, 1259, 1259, 1259,
 /*   100 */  1259, 1259, 1259, 1259, 1259, 1259, 1259, 1259, 1259, 1259,
 /*   110 */  1259, 1259, 1259, 1259, 1259, 1259, 1259, 1287, 1259, 1259,
 /*   120 */  1327, 1353, 1353,  256,  278,  278,  278,  -18,   42,   21,
 /*   130 */   152,  -17,  125,  -58,  -58,  -58,  -13,  -13,  -13,  -75,
 /*   140 */   -75,  -75,  489,  489,  321, 1306,   98,   98,  668,   68,
 /*   150 */   525,  525,  525,  628,  525,  525,  525,  525,  525,  525,
 /*   160 */   525,  525,  525,  525,  525,  525,  525,  525,  525,   68,
 /*   170 */   525,  525,  525,  525,  125,   12,   12,  185,   12,   12,
 /*   180 */    12,  185, 1795, 1795,  470,  -19,  -19,  -19,  319,  499,
 /*   190 */   -32,  -32,  148,  128,  346,  457,  202,  589,  416,  664,
 /*   200 */   697,  656,  656,  656,  683,  789,  700,  661,  695,  525,
 /*   210 */   525,  525,  525,  525,  525,  525,  525,  525,  525,  468,
 /*   220 */   877,  877,  525,  525,  894,  468,  525,  894,  525,  525,
 /*   230 */   525,  525,  525,  525,  525,  825,  525,  525,  877,  525,
 /*   240 */   243,  525,  525,  885,  525, 1060,  885,  525,  525,  525,
 /*   250 */   525, 1321, 1343, 1345, 1387, 1274, 1354, 1354, 1354, 1354,
 /*   260 */  1255, 1260, 1370, 1274, 1345, 1387, 1387, 1370, 1343, 1370,
 /*   270 */  1370, 1321, 1343, 1388, 1374, 1376, 1321, 1343, 1388, 1403,
 /*   280 */  1403, 1385, 1417, 1385, 1417, 1385, 1417, 1385, 1417, 1461,
 /*   290 */  1366, 1343, 1343, 1484, 1440, 1447, 1453, 1458, 1274, 1527,
 /*   300 */  1529, 1545, 1554, 1554, 1795, 1795, 1795,  706,  362,  486,
 /*   310 */   579,  716,  802,  363,  942,  540,  944, 1061, 1062, 1063,
 /*   320 */  1068, 1071, 1134, 1136, 1102, 1112,  433, 1113, 1149, 1150,
 /*   330 */  1151, 1132, 1159,  313, 1156, 1597, 1608, 1546, 1568, 1576,
 /*   340 */  1537, 1588, 1567, 1557, 1553, 1598, 1562, 1550, 1615, 1613,
 /*   350 */  1621, 1652, 1521, 1628, 1566, 1558, 1581, 1570, 1593, 1637,
 /*   360 */  1531, 1634, 1535, 1536, 1538, 1605, 1691, 1589, 1575, 1683,
 /*   370 */  1684, 1685, 1686, 1609, 1651, 1594, 1599, 1702, 1559, 1665,
 /*   380 */  1625, 1569, 1614, 1670, 1709, 1624, 1635, 1677, 1656, 1680,
 /*   390 */  1681, 1659, 1640, 1675, 1641, 1687, 1666, 1673, 1689, 1690,
 /*   400 */  1692, 1693, 1636, 1694, 1695, 1697, 1696, 1633, 1698, 1699,
 /*   410 */  1700, 1638, 1703, 1644, 1701, 1639, 1705, 1645, 1724, 1626,
 /*   420 */  1712, 1713, 1715, 1714, 1627, 1716, 1701, 1719, 1717, 1718,
 /*   430 */  1721, 1725, 1707, 1726, 1728, 1672, 1727, 1729, 1731, 1679,
 /*   440 */  1727, 1733, 1735, 1736, 1738, 1739, 1647, 1740, 1658, 1742,
 /*   450 */  1744, 1704, 1667, 1741, 1776, 1752, 1758, 1792, 1794,
};
#define YY_REDUCE_USE_DFLT (-183)
#define YY_REDUCE_COUNT (306)
#define YY_REDUCE_MIN   (-182)
#define YY_REDUCE_MAX   (1494)
static const short yy_reduce_ofst[] = {
 /*     0 */   151, -123,  -42,  184, -158,  -53,   31,  180,  320,  324,
 /*    10 */   539, 1217, 1234, -176,  232,  178,  532,  536,  541, 1237,
 /*    20 */  1240,  543,  689,  248,  712, -182,  923, 1004, 1032, 1205,
 /*    30 */  1209, 1214, 1226, 1242, 1246, 1249, 1251, 1257, 1266, 1278,
 /*    40 */  -148,    2, 1280, 1283, 1288, 1312, 1318, 1320, 1335, 1340,
 /*    50 */  1344, 1348, 1350, 1352, 1356, 1361, 1364, 1372, 1381, 1384,
 /*    60 */  1386, 1396, 1416, 1418, 1424, 1426, 1428, 1448, 1450, 1452,
 /*    70 */  1457, 1460, 1462, 1464, 1472, 1488, 1494,  231,  303,  -62,
 /*    80 */   263,  487,  -54,  107,  107,  107,  107,  107,  107,  107,
 /*    90 */   107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
 /*   100 */   107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
 /*   110 */   107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
 /*   120 */   107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
 /*   130 */   107,  107, -159,  337,  371,  407,  107,  107,  107,  -85,
 /*   140 */    41,   92,  336,  507,  -67,  574,  179,  192, -143,  -41,
 /*   150 */     8,  -81,    4,  530,  229,  621,  627,  665,  666,  710,
 /*   160 */   711,   19,  714,   36,  549,  223,  597,  735,  299,  634,
 /*   170 */   719,  867,  655,  760,  619,  660,  718, -150,  755,  756,
 /*   180 */   761,  -37,  653,  193,   91,  123,  227,  238,  301,  264,
 /*   190 */   389,  424,  375,  423,  511,  515,  497,  529,  577,  709,
 /*   200 */   763,  570,  737,  753,  827,  375,  839,  810,  672,  883,
 /*   210 */   895,  911,  934,  937,  940,  970, 1001, 1016, 1021,  977,
 /*   220 */   968,  971, 1034, 1036,  945,  988, 1039,  947, 1041, 1042,
 /*   230 */  1043, 1047, 1048, 1049, 1066, 1059, 1082, 1125, 1075, 1139,
 /*   240 */  1057, 1141, 1142, 1097,  763, 1096, 1100, 1147, 1177, 1191,
 /*   250 */  1203, 1124, 1127, 1081, 1174, 1164, 1179, 1180, 1181, 1182,
 /*   260 */  1135, 1140, 1232, 1190, 1171, 1207, 1211, 1244, 1225, 1248,
 /*   270 */  1256, 1239, 1254, 1263, 1273, 1276, 1281, 1264, 1279, 1290,
 /*   280 */  1293, 1252, 1258, 1261, 1269, 1265, 1270, 1277, 1282, 1268,
 /*   290 */  1291, 1319, 1323, 1250, 1324, 1333, 1336, 1351, 1349, 1398,
 /*   300 */  1404, 1407, 1412, 1414, 1406, 1409, 1419,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1322, 1297, 1297, 1297, 1042, 1356, 1239, 1239, 1239, 1239,
 /*    10 */  1189, 1239, 1239, 1042, 1042, 1356, 1356, 1356, 1356, 1356,
 /*    20 */  1356, 1356, 1197, 1356, 1297, 1110, 1356, 1356, 1356, 1356,
 /*    30 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*    40 */  1141, 1141, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*    50 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*    60 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*    70 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1055, 1055, 1042,
 /*    80 */  1356, 1297, 1114, 1147, 1356, 1356, 1356, 1240, 1241, 1356,
 /*    90 */  1356, 1356, 1356, 1196, 1356, 1356, 1267, 1158, 1157, 1156,
 /*   100 */  1155, 1124, 1153, 1145, 1149, 1185, 1190, 1194, 1193, 1240,
 /*   110 */  1236, 1237, 1235, 1198, 1195, 1191, 1241, 1356, 1186, 1148,
 /*   120 */  1207, 1220, 1206, 1216, 1226, 1217, 1209, 1208, 1210, 1211,
 /*   130 */  1212, 1213, 1356, 1061, 1061, 1061, 1223, 1222, 1221, 1356,
 /*   140 */  1356, 1356, 1356, 1356, 1356, 1246, 1356, 1356, 1356, 1081,
 /*   150 */  1356, 1356, 1356, 1297, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   160 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1081,
 /*   170 */  1356, 1356, 1356, 1356, 1356, 1297, 1297, 1055, 1297, 1297,
 /*   180 */  1297, 1055, 1114, 1105, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   190 */  1356, 1356, 1356, 1110, 1356, 1356, 1356, 1356, 1261, 1356,
 /*   200 */  1356, 1110, 1110, 1110, 1356, 1112, 1356, 1094, 1104, 1356,
 /*   210 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1152,
 /*   220 */  1126, 1126, 1356, 1356, 1353, 1152, 1356, 1353, 1356, 1356,
 /*   230 */  1356, 1356, 1356, 1356, 1356, 1141, 1356, 1356, 1126, 1356,
 /*   240 */  1238, 1356, 1356, 1104, 1356, 1111, 1104, 1356, 1356, 1356,
 /*   250 */  1356, 1067, 1247, 1163, 1084, 1152, 1091, 1091, 1091, 1091,
 /*   260 */  1266, 1265, 1034, 1152, 1163, 1084, 1084, 1034, 1247, 1034,
 /*   270 */  1034, 1067, 1247, 1075, 1058, 1057, 1067, 1247, 1075, 1082,
 /*   280 */  1082, 1130, 1125, 1130, 1125, 1130, 1125, 1130, 1125, 1242,
 /*   290 */  1356, 1247, 1247, 1356, 1146, 1131, 1144, 1142, 1152, 1356,
 /*   300 */  1329, 1356, 1325, 1325, 1336, 1336, 1037, 1356, 1356, 1356,
 /*   310 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   320 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   330 */  1356, 1356, 1356, 1169, 1356, 1356, 1024, 1356, 1356, 1356,
 /*   340 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1283, 1356, 1356,
 /*   350 */  1253, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   360 */  1356, 1264, 1263, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   370 */  1356, 1356, 1356, 1356, 1356, 1356, 1352, 1356, 1356, 1356,
 /*   380 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   390 */  1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   400 */  1356, 1356, 1096, 1356, 1356, 1356, 1342, 1356, 1356, 1356,
 /*   410 */  1356, 1356, 1356, 1356, 1143, 1356, 1132, 1356, 1184, 1356,
 /*   420 */  1356, 1356, 1356, 1348, 1356, 1356, 1350, 1356, 1356, 1356,
 /*   430 */  1356, 1356, 1356, 1356, 1356, 1356, 1299, 1356, 1356, 1356,
 /*   440 */  1298, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356, 1356,
 /*   450 */  1356, 1356, 1356, 1356, 1356, 1028, 1356, 1356, 1356,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   50,  /*      QUERY => ID */
   50,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   50,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*         LB => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   50,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   50,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   50,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   50,  /*      ABORT => ID */
   50,  /*     ACTION => ID */
   50,  /*        ADD => ID */
   50,  /*      AFTER => ID */
   50,  /* AUTOINCREMENT => ID */
   50,  /*     BEFORE => ID */
   50,  /*    CASCADE => ID */
   50,  /*   CONFLICT => ID */
   50,  /*   DEFERRED => ID */
   50,  /*        END => ID */
   50,  /*       FAIL => ID */
   50,  /*     IGNORE => ID */
   50,  /*  INITIALLY => ID */
   50,  /*    INSTEAD => ID */
   50,  /*         NO => ID */
   50,  /*        KEY => ID */
   50,  /*     OFFSET => ID */
   50,  /*      RAISE => ID */
   50,  /*    REPLACE => ID */
   50,  /*   RESTRICT => ID */
   50,  /*     RENAME => ID */
   50,  /*   CTIME_KW => ID */
   50,  /*     ENABLE => ID */
   50,  /*    DISABLE => ID */
   50,  /*       UUID => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "LB",            "START",         "TRANSACTION",   "COMMIT",      
  "ROLLBACK",      "SAVEPOINT",     "RELEASE",       "TO",          
  "TABLE",         "CREATE",        "IF",            "EXISTS",      
  "LP",            "RP",            "WITH",          "ENGINE",      
  "STRING",        "COMMA",         "ID",            "INDEXED",     
  "ABORT",         "ACTION",        "ADD",           "AFTER",       
  "AUTOINCREMENT",  "BEFORE",        "CASCADE",       "CONFLICT",    
  "DEFERRED",      "END",           "FAIL",          "IGNORE",      
  "INITIALLY",     "INSTEAD",       "NO",            "KEY",         
  "OFFSET",        "RAISE",         "REPLACE",       "RESTRICT",    
  "RENAME",        "CTIME_KW",      "ENABLE",        "DISABLE",     
  "UUID",          "WILDCARD",      "CONSTRAINT",    "DEFAULT",     
  "NULL",          "PRIMARY",       "UNIQUE",        "CHECK",       
  "REFERENCES",    "AUTOINCR",      "ON",            "UPDATE",      
  "DELETE",        "SIMPLE",        "PARTIAL",       "FULL",        
  "SET",           "DEFERRABLE",    "IMMEDIATE",     "FOREIGN",     
  "DROP",          "VIEW",          "AS",            "UNION",       
  "ALL",           "EXCEPT",        "INTERSECT",     "SELECT",      
  "VALUES",        "DISTINCT",      "DOT",           "FROM",        
  "JOIN_KW",       "JOIN",          "BY",            "USING",       
  "ORDER",         "ASC",           "DESC",          "GROUP",       
  "HAVING",        "LIMIT",         "TRUNCATE",      "WHERE",       
  "INTO",          "INSERT",        "FLOAT",         "BLOB",        
  "FALSE",         "TRUE",          "UNKNOWN",       "DECIMAL",     
  "INTEGER",       "VARNUM",        "COLON",         "VARIABLE",    
  "CAST",          "RB",            "LCB",           "RCB",         
  "TRIM",          "LEADING",       "TRAILING",      "BOTH",        
  "CHAR",          "CASE",          "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "SESSION",       "PRAGMA",      
  "BEGIN",         "TRIGGER",       "OF",            "FOR",         
  "EACH",          "ROW",           "ALTER",         "COLUMN",      
  "RECURSIVE",     "TEXT",          "STRING_KW",     "SCALAR",      
  "BOOL",          "BOOLEAN",       "VARBINARY",     "ANY",         
  "ARRAY",         "MAP",           "DATETIME",      "INTERVAL",    
  "VARCHAR",       "NUMBER",        "DOUBLE",        "INT",         
  "INTEGER_KW",    "UNSIGNED",      "error",         "input",       
  "ecmd",          "explain",       "cmdx",          "cmd",         
  "savepoint_opt",  "nm",            "create_table",  "create_table_args",
  "with_opts",     "create_table_end",  "createkw",      "ifnotexists", 
  "columnlist",    "engine_opts",   "tcons",         "column_def",  
  "create_column_end",  "column_name_and_type",  "carglist",      "typedef",     
  "autoinc",       "ccons",         "cconsname",     "term",        
  "expr",          "onconf",        "sortorder",     "check_constraint_def",
  "eidlist_opt",   "matcharg",      "refargs",       "defer_subclause",
  "refact_update",  "refact_delete",  "refact",        "init_deferred_pred_opt",
  "col_list_with_autoinc",  "sortlist",      "eidlist",       "defer_subclause_opt",
  "index_onconf",  "orconf",        "resolvetype",   "raisetype",   
  "ifexists",      "fullname",      "select",        "selectnowith",
  "oneselect",     "with",          "multiselect_op",  "distinct",    
  "selcollist",    "from",          "where_opt",     "groupby_opt", 
  "having_opt",    "orderby_opt",   "limit_opt",     "values",      
  "nexprlist",     "exprlist",      "sclp",          "as",          
  "seltablist",    "stl_prefix",    "joinop",        "indexed_opt", 
  "on_opt",        "using_opt",     "join_nm",       "idlist",      
  "enable",        "setlist",       "insert_cmd",    "idlist_opt",  
  "getlist",       "maplist",       "nmaplist",      "trim_operands",
  "trim_specification",  "expr_optional",  "type_func",     "likeop",      
  "between_op",    "in_op",         "paren_exprlist",  "case_exprlist",
  "case_else",     "uniqueflag",    "trigger_decl",  "trigger_cmd_list",
  "trigger_time",  "trigger_event",  "foreach_clause",  "when_clause", 
  "trigger_cmd",   "trnm",          "tridxby",       "alter_table_start",
  "alter_add_constraint",  "alter_add_column",  "column_name",   "alter_column_def",
  "unique_spec",   "wqlist",        "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "column_name_and_type ::= nm typedef",
 /*  17 */ "create_column_end ::= autoinc",
 /*  18 */ "nm ::= ID|INDEXED",
 /*  19 */ "cconsname ::= CONSTRAINT nm",
 /*  20 */ "cconsname ::=",
 /*  21 */ "ccons ::= DEFAULT term",
 /*  22 */ "ccons ::= DEFAULT LP expr RP",
 /*  23 */ "ccons ::= DEFAULT PLUS term",
 /*  24 */ "ccons ::= DEFAULT MINUS term",
 /*  25 */ "ccons ::= NULL onconf",
 /*  26 */ "ccons ::= NOT NULL onconf",
 /*  27 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  28 */ "ccons ::= cconsname UNIQUE",
 /*  29 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  30 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  31 */ "ccons ::= defer_subclause",
 /*  32 */ "ccons ::= COLLATE ID|INDEXED",
 /*  33 */ "autoinc ::=",
 /*  34 */ "autoinc ::= AUTOINCR",
 /*  35 */ "refargs ::= refact_update",
 /*  36 */ "refargs ::= refact_delete",
 /*  37 */ "refargs ::= refact_delete refact_update",
 /*  38 */ "refargs ::= refact_update refact_delete",
 /*  39 */ "refargs ::=",
 /*  40 */ "refact_update ::= ON UPDATE refact",
 /*  41 */ "refact_delete ::= ON DELETE refact",
 /*  42 */ "matcharg ::= MATCH SIMPLE",
 /*  43 */ "matcharg ::= MATCH PARTIAL",
 /*  44 */ "matcharg ::= MATCH FULL",
 /*  45 */ "matcharg ::=",
 /*  46 */ "refact ::= SET NULL",
 /*  47 */ "refact ::= SET DEFAULT",
 /*  48 */ "refact ::= CASCADE",
 /*  49 */ "refact ::= RESTRICT",
 /*  50 */ "refact ::= NO ACTION",
 /*  51 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  52 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "init_deferred_pred_opt ::=",
 /*  54 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  56 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  57 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  58 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  59 */ "defer_subclause_opt ::=",
 /*  60 */ "onconf ::=",
 /*  61 */ "onconf ::= ON CONFLICT resolvetype",
 /*  62 */ "orconf ::=",
 /*  63 */ "orconf ::= OR resolvetype",
 /*  64 */ "resolvetype ::= IGNORE",
 /*  65 */ "resolvetype ::= REPLACE",
 /*  66 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  67 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  68 */ "ifexists ::= IF EXISTS",
 /*  69 */ "ifexists ::=",
 /*  70 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  71 */ "cmd ::= select",
 /*  72 */ "select ::= with selectnowith",
 /*  73 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  74 */ "multiselect_op ::= UNION",
 /*  75 */ "multiselect_op ::= UNION ALL",
 /*  76 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  77 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  78 */ "values ::= VALUES LP nexprlist RP",
 /*  79 */ "values ::= values COMMA LP exprlist RP",
 /*  80 */ "distinct ::= DISTINCT",
 /*  81 */ "distinct ::= ALL",
 /*  82 */ "distinct ::=",
 /*  83 */ "sclp ::=",
 /*  84 */ "selcollist ::= sclp expr as",
 /*  85 */ "selcollist ::= sclp STAR",
 /*  86 */ "selcollist ::= sclp nm DOT STAR",
 /*  87 */ "as ::= AS nm",
 /*  88 */ "as ::=",
 /*  89 */ "from ::=",
 /*  90 */ "from ::= FROM seltablist",
 /*  91 */ "stl_prefix ::= seltablist joinop",
 /*  92 */ "stl_prefix ::=",
 /*  93 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  97 */ "fullname ::= nm",
 /*  98 */ "joinop ::= COMMA|JOIN",
 /*  99 */ "joinop ::= JOIN_KW JOIN",
 /* 100 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 102 */ "on_opt ::= ON expr",
 /* 103 */ "on_opt ::=",
 /* 104 */ "indexed_opt ::=",
 /* 105 */ "indexed_opt ::= INDEXED BY nm",
 /* 106 */ "indexed_opt ::= NOT INDEXED",
 /* 107 */ "using_opt ::= USING LP idlist RP",
 /* 108 */ "using_opt ::=",
 /* 109 */ "orderby_opt ::=",
 /* 110 */ "orderby_opt ::= ORDER BY sortlist",
 /* 111 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 112 */ "sortlist ::= expr sortorder",
 /* 113 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 114 */ "col_list_with_autoinc ::= expr autoinc",
 /* 115 */ "enable ::= ENABLE",
 /* 116 */ "enable ::= DISABLE",
 /* 117 */ "sortorder ::= ASC",
 /* 118 */ "sortorder ::= DESC",
 /* 119 */ "sortorder ::=",
 /* 120 */ "groupby_opt ::=",
 /* 121 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 122 */ "having_opt ::=",
 /* 123 */ "having_opt ::= HAVING expr",
 /* 124 */ "limit_opt ::=",
 /* 125 */ "limit_opt ::= LIMIT expr",
 /* 126 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 127 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 128 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 129 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 130 */ "where_opt ::=",
 /* 131 */ "where_opt ::= WHERE expr",
 /* 132 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 133 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 134 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 135 */ "setlist ::= nm EQ expr",
 /* 136 */ "setlist ::= LP idlist RP EQ expr",
 /* 137 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 139 */ "insert_cmd ::= INSERT orconf",
 /* 140 */ "insert_cmd ::= REPLACE",
 /* 141 */ "idlist_opt ::=",
 /* 142 */ "idlist_opt ::= LP idlist RP",
 /* 143 */ "idlist ::= idlist COMMA nm",
 /* 144 */ "idlist ::= nm",
 /* 145 */ "expr ::= LP expr RP",
 /* 146 */ "term ::= NULL",
 /* 147 */ "expr ::= ID|INDEXED",
 /* 148 */ "expr ::= JOIN_KW",
 /* 149 */ "expr ::= nm DOT nm",
 /* 150 */ "term ::= FLOAT|BLOB",
 /* 151 */ "term ::= STRING",
 /* 152 */ "term ::= FALSE",
 /* 153 */ "term ::= TRUE",
 /* 154 */ "term ::= UNKNOWN",
 /* 155 */ "term ::= DECIMAL",
 /* 156 */ "term ::= INTEGER",
 /* 157 */ "expr ::= VARNUM",
 /* 158 */ "expr ::= COLON|VARIABLE ID|INDEXED",
 /* 159 */ "expr ::= COLON|VARIABLE INTEGER",
 /* 160 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 161 */ "expr ::= CAST LP expr AS typedef RP",
 /* 162 */ "expr ::= expr LB getlist RB",
 /* 163 */ "getlist ::= getlist RB LB expr",
 /* 164 */ "getlist ::= expr",
 /* 165 */ "expr ::= LB exprlist RB",
 /* 166 */ "expr ::= LCB maplist RCB",
 /* 167 */ "maplist ::=",
 /* 168 */ "nmaplist ::= nmaplist COMMA expr COLON expr",
 /* 169 */ "nmaplist ::= expr COLON expr",
 /* 170 */ "expr ::= TRIM LP trim_operands RP",
 /* 171 */ "trim_operands ::= trim_specification expr FROM expr",
 /* 172 */ "trim_operands ::= trim_specification FROM expr",
 /* 173 */ "trim_operands ::= expr FROM expr",
 /* 174 */ "trim_operands ::= expr",
 /* 175 */ "expr_optional ::=",
 /* 176 */ "expr_optional ::= expr",
 /* 177 */ "trim_specification ::= LEADING",
 /* 178 */ "trim_specification ::= TRAILING",
 /* 179 */ "trim_specification ::= BOTH",
 /* 180 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 181 */ "expr ::= type_func LP distinct exprlist RP",
 /* 182 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 183 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 184 */ "expr ::= expr AND expr",
 /* 185 */ "expr ::= expr OR expr",
 /* 186 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 187 */ "expr ::= expr EQ|NE expr",
 /* 188 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 189 */ "expr ::= expr PLUS|MINUS expr",
 /* 190 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 191 */ "expr ::= expr CONCAT expr",
 /* 192 */ "likeop ::= LIKE_KW|MATCH",
 /* 193 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 194 */ "expr ::= expr likeop expr",
 /* 195 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 196 */ "expr ::= expr IS NULL",
 /* 197 */ "expr ::= expr IS NOT NULL",
 /* 198 */ "expr ::= NOT expr",
 /* 199 */ "expr ::= BITNOT expr",
 /* 200 */ "expr ::= MINUS expr",
 /* 201 */ "expr ::= PLUS expr",
 /* 202 */ "between_op ::= BETWEEN",
 /* 203 */ "between_op ::= NOT BETWEEN",
 /* 204 */ "expr ::= expr between_op expr AND expr",
 /* 205 */ "in_op ::= IN",
 /* 206 */ "in_op ::= NOT IN",
 /* 207 */ "expr ::= expr in_op LP exprlist RP",
 /* 208 */ "expr ::= LP select RP",
 /* 209 */ "expr ::= expr in_op LP select RP",
 /* 210 */ "expr ::= expr in_op nm paren_exprlist",
 /* 211 */ "expr ::= EXISTS LP select RP",
 /* 212 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 213 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 214 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 215 */ "case_else ::= ELSE expr",
 /* 216 */ "case_else ::=",
 /* 217 */ "exprlist ::=",
 /* 218 */ "nexprlist ::= nexprlist COMMA expr",
 /* 219 */ "nexprlist ::= expr",
 /* 220 */ "paren_exprlist ::=",
 /* 221 */ "paren_exprlist ::= LP exprlist RP",
 /* 222 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 223 */ "uniqueflag ::= UNIQUE",
 /* 224 */ "uniqueflag ::=",
 /* 225 */ "eidlist_opt ::=",
 /* 226 */ "eidlist_opt ::= LP eidlist RP",
 /* 227 */ "eidlist ::= eidlist COMMA nm",
 /* 228 */ "eidlist ::= nm",
 /* 229 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 230 */ "cmd ::= SET SESSION nm EQ term",
 /* 231 */ "cmd ::= PRAGMA nm",
 /* 232 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 233 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 234 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 235 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 236 */ "trigger_time ::= BEFORE",
 /* 237 */ "trigger_time ::= AFTER",
 /* 238 */ "trigger_time ::= INSTEAD OF",
 /* 239 */ "trigger_time ::=",
 /* 240 */ "trigger_event ::= DELETE|INSERT",
 /* 241 */ "trigger_event ::= UPDATE",
 /* 242 */ "trigger_event ::= UPDATE OF idlist",
 /* 243 */ "foreach_clause ::=",
 /* 244 */ "when_clause ::=",
 /* 245 */ "when_clause ::= WHEN expr",
 /* 246 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 247 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 248 */ "trnm ::= nm DOT nm",
 /* 249 */ "tridxby ::= INDEXED BY nm",
 /* 250 */ "tridxby ::= NOT INDEXED",
 /* 251 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 252 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 253 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 254 */ "trigger_cmd ::= select",
 /* 255 */ "expr ::= RAISE LP IGNORE RP",
 /* 256 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 257 */ "raisetype ::= ROLLBACK",
 /* 258 */ "raisetype ::= ABORT",
 /* 259 */ "raisetype ::= FAIL",
 /* 260 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 261 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 262 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 263 */ "alter_add_column ::= alter_table_start ADD column_name",
 /* 264 */ "column_name ::= COLUMN nm",
 /* 265 */ "column_name ::= nm",
 /* 266 */ "alter_column_def ::= alter_add_column typedef",
 /* 267 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 268 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 269 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 270 */ "unique_spec ::= UNIQUE",
 /* 271 */ "unique_spec ::= PRIMARY KEY",
 /* 272 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 273 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 274 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 275 */ "with ::=",
 /* 276 */ "with ::= WITH wqlist",
 /* 277 */ "with ::= WITH RECURSIVE wqlist",
 /* 278 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 279 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 280 */ "typedef ::= TEXT",
 /* 281 */ "typedef ::= STRING_KW",
 /* 282 */ "typedef ::= SCALAR",
 /* 283 */ "typedef ::= BOOL",
 /* 284 */ "typedef ::= BOOLEAN",
 /* 285 */ "typedef ::= VARBINARY",
 /* 286 */ "typedef ::= UUID",
 /* 287 */ "typedef ::= ANY",
 /* 288 */ "typedef ::= ARRAY",
 /* 289 */ "typedef ::= MAP",
 /* 290 */ "typedef ::= DATETIME",
 /* 291 */ "typedef ::= INTERVAL",
 /* 292 */ "char_len ::= LP INTEGER RP",
 /* 293 */ "typedef ::= VARCHAR char_len",
 /* 294 */ "number_typedef ::= NUMBER",
 /* 295 */ "number_typedef ::= DOUBLE",
 /* 296 */ "number_typedef ::= INT|INTEGER_KW",
 /* 297 */ "number_typedef ::= UNSIGNED",
 /* 298 */ "number_typedef ::= DECIMAL",
 /* 299 */ "input ::= ecmd",
 /* 300 */ "explain ::=",
 /* 301 */ "cmdx ::= cmd",
 /* 302 */ "savepoint_opt ::= SAVEPOINT",
 /* 303 */ "savepoint_opt ::=",
 /* 304 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 305 */ "create_table_args ::= LP columnlist RP",
 /* 306 */ "with_opts ::= WITH engine_opts",
 /* 307 */ "with_opts ::=",
 /* 308 */ "columnlist ::= columnlist COMMA tcons",
 /* 309 */ "columnlist ::= columnlist COMMA column_def create_column_end",
 /* 310 */ "columnlist ::= column_def create_column_end",
 /* 311 */ "column_def ::= column_name_and_type carglist",
 /* 312 */ "columnlist ::= tcons",
 /* 313 */ "carglist ::= carglist ccons",
 /* 314 */ "carglist ::=",
 /* 315 */ "ccons ::= check_constraint_def",
 /* 316 */ "tcons ::= check_constraint_def",
 /* 317 */ "defer_subclause_opt ::= defer_subclause",
 /* 318 */ "resolvetype ::= raisetype",
 /* 319 */ "selectnowith ::= oneselect",
 /* 320 */ "oneselect ::= values",
 /* 321 */ "sclp ::= selcollist COMMA",
 /* 322 */ "as ::= ID|STRING",
 /* 323 */ "join_nm ::= ID|INDEXED",
 /* 324 */ "join_nm ::= JOIN_KW",
 /* 325 */ "expr ::= term",
 /* 326 */ "maplist ::= nmaplist",
 /* 327 */ "type_func ::= CHAR",
 /* 328 */ "exprlist ::= nexprlist",
 /* 329 */ "foreach_clause ::= FOR EACH ROW",
 /* 330 */ "trnm ::= nm",
 /* 331 */ "tridxby ::=",
 /* 332 */ "cmd ::= alter_column_def carglist create_column_end",
 /* 333 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 199: /* term */
    case 200: /* expr */
{
#line 961 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy358).pExpr);
#line 1650 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 204: /* eidlist_opt */
    case 212: /* col_list_with_autoinc */
    case 213: /* sortlist */
    case 214: /* eidlist */
    case 228: /* selcollist */
    case 231: /* groupby_opt */
    case 233: /* orderby_opt */
    case 236: /* nexprlist */
    case 237: /* exprlist */
    case 238: /* sclp */
    case 249: /* setlist */
    case 262: /* paren_exprlist */
    case 263: /* case_exprlist */
{
#line 1565 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy442));
#line 1669 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 221: /* fullname */
    case 229: /* from */
    case 240: /* seltablist */
    case 241: /* stl_prefix */
{
#line 710 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy147));
#line 1679 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 222: /* select */
    case 223: /* selectnowith */
    case 224: /* oneselect */
    case 235: /* values */
{
#line 474 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy491));
#line 1689 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 225: /* with */
    case 281: /* wqlist */
{
#line 1863 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy523));
#line 1697 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 230: /* where_opt */
    case 232: /* having_opt */
    case 244: /* on_opt */
    case 264: /* case_else */
    case 271: /* when_clause */
{
#line 870 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy130));
#line 1708 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 245: /* using_opt */
    case 247: /* idlist */
    case 251: /* idlist_opt */
{
#line 753 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy200));
#line 1717 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 252: /* getlist */
    case 253: /* maplist */
    case 254: /* nmaplist */
{
#line 1125 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy142));
#line 1726 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 255: /* trim_operands */
{
#line 1180 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy359));
#line 1733 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 257: /* expr_optional */
{
#line 1213 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy71));
#line 1740 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 267: /* trigger_cmd_list */
    case 272: /* trigger_cmd */
{
#line 1664 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy524));
#line 1748 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
    case 269: /* trigger_event */
{
#line 1645 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy498).b);
#line 1755 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1931 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 176, 3 },
  { 176, 1 },
  { 177, 1 },
  { 177, 3 },
  { 179, 2 },
  { 179, 1 },
  { 179, 1 },
  { 179, 2 },
  { 179, 3 },
  { 179, 4 },
  { 182, 4 },
  { 186, 1 },
  { 187, 0 },
  { 187, 3 },
  { 189, 3 },
  { 185, 0 },
  { 193, 2 },
  { 192, 1 },
  { 181, 1 },
  { 198, 2 },
  { 198, 0 },
  { 197, 2 },
  { 197, 4 },
  { 197, 3 },
  { 197, 3 },
  { 197, 2 },
  { 197, 3 },
  { 197, 4 },
  { 197, 2 },
  { 203, 5 },
  { 197, 6 },
  { 197, 1 },
  { 197, 2 },
  { 196, 0 },
  { 196, 1 },
  { 206, 1 },
  { 206, 1 },
  { 206, 2 },
  { 206, 2 },
  { 206, 0 },
  { 208, 3 },
  { 209, 3 },
  { 205, 2 },
  { 205, 2 },
  { 205, 2 },
  { 205, 0 },
  { 210, 2 },
  { 210, 2 },
  { 210, 1 },
  { 210, 1 },
  { 210, 2 },
  { 207, 3 },
  { 207, 2 },
  { 211, 0 },
  { 211, 2 },
  { 211, 2 },
  { 190, 6 },
  { 190, 5 },
  { 190, 12 },
  { 215, 0 },
  { 201, 0 },
  { 201, 3 },
  { 217, 0 },
  { 217, 2 },
  { 218, 1 },
  { 218, 1 },
  { 179, 4 },
  { 179, 4 },
  { 220, 2 },
  { 220, 0 },
  { 179, 7 },
  { 179, 1 },
  { 222, 2 },
  { 223, 3 },
  { 226, 1 },
  { 226, 2 },
  { 226, 1 },
  { 224, 9 },
  { 235, 4 },
  { 235, 5 },
  { 227, 1 },
  { 227, 1 },
  { 227, 0 },
  { 238, 0 },
  { 228, 3 },
  { 228, 2 },
  { 228, 4 },
  { 239, 2 },
  { 239, 0 },
  { 229, 0 },
  { 229, 2 },
  { 241, 2 },
  { 241, 0 },
  { 240, 6 },
  { 240, 8 },
  { 240, 7 },
  { 240, 7 },
  { 221, 1 },
  { 242, 1 },
  { 242, 2 },
  { 242, 3 },
  { 242, 4 },
  { 244, 2 },
  { 244, 0 },
  { 243, 0 },
  { 243, 3 },
  { 243, 2 },
  { 245, 4 },
  { 245, 0 },
  { 233, 0 },
  { 233, 3 },
  { 213, 4 },
  { 213, 2 },
  { 212, 4 },
  { 212, 2 },
  { 248, 1 },
  { 248, 1 },
  { 202, 1 },
  { 202, 1 },
  { 202, 0 },
  { 231, 0 },
  { 231, 3 },
  { 232, 0 },
  { 232, 2 },
  { 234, 0 },
  { 234, 2 },
  { 234, 4 },
  { 234, 4 },
  { 179, 6 },
  { 179, 3 },
  { 230, 0 },
  { 230, 2 },
  { 179, 8 },
  { 249, 5 },
  { 249, 7 },
  { 249, 3 },
  { 249, 5 },
  { 179, 6 },
  { 179, 7 },
  { 250, 2 },
  { 250, 1 },
  { 251, 0 },
  { 251, 3 },
  { 247, 3 },
  { 247, 1 },
  { 200, 3 },
  { 199, 1 },
  { 200, 1 },
  { 200, 1 },
  { 200, 3 },
  { 199, 1 },
  { 199, 1 },
  { 199, 1 },
  { 199, 1 },
  { 199, 1 },
  { 199, 1 },
  { 199, 1 },
  { 200, 1 },
  { 200, 2 },
  { 200, 2 },
  { 200, 3 },
  { 200, 6 },
  { 200, 4 },
  { 252, 4 },
  { 252, 1 },
  { 200, 3 },
  { 200, 3 },
  { 253, 0 },
  { 254, 5 },
  { 254, 3 },
  { 200, 4 },
  { 255, 4 },
  { 255, 3 },
  { 255, 3 },
  { 255, 1 },
  { 257, 0 },
  { 257, 1 },
  { 256, 1 },
  { 256, 1 },
  { 256, 1 },
  { 200, 5 },
  { 200, 5 },
  { 200, 4 },
  { 200, 5 },
  { 200, 3 },
  { 200, 3 },
  { 200, 3 },
  { 200, 3 },
  { 200, 3 },
  { 200, 3 },
  { 200, 3 },
  { 200, 3 },
  { 259, 1 },
  { 259, 2 },
  { 200, 3 },
  { 200, 5 },
  { 200, 3 },
  { 200, 4 },
  { 200, 2 },
  { 200, 2 },
  { 200, 2 },
  { 200, 2 },
  { 260, 1 },
  { 260, 2 },
  { 200, 5 },
  { 261, 1 },
  { 261, 2 },
  { 200, 5 },
  { 200, 3 },
  { 200, 5 },
  { 200, 4 },
  { 200, 4 },
  { 200, 5 },
  { 263, 5 },
  { 263, 4 },
  { 264, 2 },
  { 264, 0 },
  { 237, 0 },
  { 236, 3 },
  { 236, 1 },
  { 262, 0 },
  { 262, 3 },
  { 179, 10 },
  { 265, 1 },
  { 265, 0 },
  { 204, 0 },
  { 204, 3 },
  { 214, 3 },
  { 214, 1 },
  { 179, 6 },
  { 179, 5 },
  { 179, 2 },
  { 179, 5 },
  { 179, 7 },
  { 179, 5 },
  { 266, 9 },
  { 268, 1 },
  { 268, 1 },
  { 268, 2 },
  { 268, 0 },
  { 269, 1 },
  { 269, 1 },
  { 269, 3 },
  { 270, 0 },
  { 271, 0 },
  { 271, 2 },
  { 267, 3 },
  { 267, 2 },
  { 273, 3 },
  { 274, 3 },
  { 274, 2 },
  { 272, 7 },
  { 272, 5 },
  { 272, 5 },
  { 272, 1 },
  { 200, 4 },
  { 200, 6 },
  { 219, 1 },
  { 219, 1 },
  { 219, 1 },
  { 179, 4 },
  { 275, 3 },
  { 276, 4 },
  { 277, 3 },
  { 278, 2 },
  { 278, 1 },
  { 279, 2 },
  { 179, 12 },
  { 179, 5 },
  { 179, 5 },
  { 280, 1 },
  { 280, 2 },
  { 179, 4 },
  { 179, 6 },
  { 179, 5 },
  { 225, 0 },
  { 225, 2 },
  { 225, 3 },
  { 281, 6 },
  { 281, 8 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 1 },
  { 282, 3 },
  { 195, 2 },
  { 283, 1 },
  { 283, 1 },
  { 283, 1 },
  { 283, 1 },
  { 283, 1 },
  { 175, 1 },
  { 177, 0 },
  { 178, 1 },
  { 180, 1 },
  { 180, 0 },
  { 179, 4 },
  { 183, 3 },
  { 184, 2 },
  { 184, 0 },
  { 188, 3 },
  { 188, 4 },
  { 188, 2 },
  { 191, 2 },
  { 188, 1 },
  { 194, 2 },
  { 194, 0 },
  { 197, 1 },
  { 190, 1 },
  { 215, 1 },
  { 218, 1 },
  { 223, 1 },
  { 224, 1 },
  { 238, 2 },
  { 239, 1 },
  { 246, 1 },
  { 246, 1 },
  { 200, 1 },
  { 253, 1 },
  { 258, 1 },
  { 237, 1 },
  { 270, 3 },
  { 273, 1 },
  { 274, 0 },
  { 179, 3 },
  { 195, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2408 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2416 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2421 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2426 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 164 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2431 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 165 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2436 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 166 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2441 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 170 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2448 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 173 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2455 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 176 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2462 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 183 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy420);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2473 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 190 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2478 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 33: /* autoinc ::= */ yytestcase(yyruleno==33);
      case 53: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==53);
      case 59: /* defer_subclause_opt ::= */ yytestcase(yyruleno==59);
      case 69: /* ifexists ::= */ yytestcase(yyruleno==69);
      case 82: /* distinct ::= */ yytestcase(yyruleno==82);
#line 193 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy420 = 0;}
#line 2488 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 194 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy420 = 1;}
#line 2493 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 201 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2514 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 219 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2519 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 16: /* column_name_and_type ::= nm typedef */
#line 237 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, NULL, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy194);
  sql_create_column_start(pParse);
}
#line 2527 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 17: /* create_column_end ::= autoinc */
#line 242 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_column_def.space->def->field_count - 1;
  if (yymsp[0].minor.yy420 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
  if (pParse->create_table_def.new_space == NULL)
    sql_create_column_end(pParse);
}
#line 2538 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 18: /* nm ::= ID|INDEXED */
#line 284 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2549 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 19: /* cconsname ::= CONSTRAINT nm */
#line 300 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy375 = yymsp[0].minor.yy0; }
#line 2554 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 20: /* cconsname ::= */
#line 301 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[1].minor.yy375 = Token_nil; }
#line 2559 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 21: /* ccons ::= DEFAULT term */
      case 23: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==23);
#line 302 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy358);}
#line 2565 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 22: /* ccons ::= DEFAULT LP expr RP */
#line 303 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy358);}
#line 2570 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 24: /* ccons ::= DEFAULT MINUS term */
#line 305 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy358.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy358.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2581 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 25: /* ccons ::= NULL onconf */
#line 316 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy420 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy420);
}
#line 2591 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 26: /* ccons ::= NOT NULL onconf */
#line 322 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy420);}
#line 2596 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 27: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 323 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy375, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy420, false);
  sqlAddPrimaryKey(pParse);
}
#line 2605 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 28: /* ccons ::= cconsname UNIQUE */
#line 328 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy375, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2615 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 29: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 337 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy375, &yymsp[-1].minor.yy358);
  sql_create_check_contraint(pParse);
}
#line 2623 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 30: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 342 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy375, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy442, yymsp[-1].minor.yy420, yymsp[0].minor.yy420,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2632 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 31: /* ccons ::= defer_subclause */
#line 347 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy420);}
#line 2637 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 32: /* ccons ::= COLLATE ID|INDEXED */
#line 348 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2642 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 34: /* autoinc ::= AUTOINCR */
#line 353 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = 1;}
#line 2647 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 35: /* refargs ::= refact_update */
#line 361 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yylhsminor.yy420 = (yymsp[0].minor.yy420 << 8); }
#line 2652 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy420 = yylhsminor.yy420;
        break;
      case 36: /* refargs ::= refact_delete */
#line 362 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yylhsminor.yy420 = yymsp[0].minor.yy420; }
#line 2658 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy420 = yylhsminor.yy420;
        break;
      case 37: /* refargs ::= refact_delete refact_update */
#line 363 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yylhsminor.yy420 = (yymsp[0].minor.yy420 << 8) | (yymsp[-1].minor.yy420) ; }
#line 2664 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-1].minor.yy420 = yylhsminor.yy420;
        break;
      case 38: /* refargs ::= refact_update refact_delete */
#line 364 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yylhsminor.yy420 = (yymsp[-1].minor.yy420 << 8) | (yymsp[0].minor.yy420) ; }
#line 2670 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-1].minor.yy420 = yylhsminor.yy420;
        break;
      case 39: /* refargs ::= */
#line 365 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[1].minor.yy420 = 0; }
#line 2676 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 40: /* refact_update ::= ON UPDATE refact */
      case 41: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==41);
#line 368 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-2].minor.yy420 = yymsp[0].minor.yy420; }
#line 2682 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 42: /* matcharg ::= MATCH SIMPLE */
#line 373 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = FKEY_MATCH_SIMPLE; }
#line 2687 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 43: /* matcharg ::= MATCH PARTIAL */
#line 374 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = FKEY_MATCH_PARTIAL; }
#line 2692 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 44: /* matcharg ::= MATCH FULL */
#line 375 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = FKEY_MATCH_FULL; }
#line 2697 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 45: /* matcharg ::= */
#line 376 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[1].minor.yy420 = FKEY_MATCH_SIMPLE; }
#line 2702 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 46: /* refact ::= SET NULL */
#line 379 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = FKEY_ACTION_SET_NULL; }
#line 2707 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 47: /* refact ::= SET DEFAULT */
#line 380 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = FKEY_ACTION_SET_DEFAULT; }
#line 2712 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 48: /* refact ::= CASCADE */
#line 381 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy420 = FKEY_ACTION_CASCADE; }
#line 2717 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 49: /* refact ::= RESTRICT */
#line 382 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy420 = FKEY_ACTION_RESTRICT; }
#line 2722 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 50: /* refact ::= NO ACTION */
#line 383 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = FKEY_NO_ACTION; }
#line 2727 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 51: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 385 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy420 = 0;}
#line 2732 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 52: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 63: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==63);
      case 139: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==139);
#line 386 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy420 = yymsp[0].minor.yy420;}
#line 2739 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 54: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 68: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==68);
      case 203: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==203);
      case 206: /* in_op ::= NOT IN */ yytestcase(yyruleno==206);
#line 389 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy420 = 1;}
#line 2747 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 390 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy420 = 0;}
#line 2752 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 56: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 392 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy375, yymsp[-1].minor.yy442,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2761 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 57: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 397 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy375, yymsp[-1].minor.yy442,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2771 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 58: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 405 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy375, yymsp[-7].minor.yy442, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy442, yymsp[-2].minor.yy420, yymsp[-1].minor.yy420, yymsp[0].minor.yy420);
  sql_create_foreign_key(pParse);
}
#line 2779 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 60: /* onconf ::= */
#line 420 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy420 = ON_CONFLICT_ACTION_ABORT;}
#line 2784 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 61: /* onconf ::= ON CONFLICT resolvetype */
#line 421 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy420 = yymsp[0].minor.yy420;}
#line 2789 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 62: /* orconf ::= */
#line 422 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy420 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2794 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 64: /* resolvetype ::= IGNORE */
#line 425 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = ON_CONFLICT_ACTION_IGNORE;}
#line 2799 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 65: /* resolvetype ::= REPLACE */
      case 140: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==140);
#line 426 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = ON_CONFLICT_ACTION_REPLACE;}
#line 2805 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 66: /* cmd ::= DROP TABLE ifexists fullname */
#line 431 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy147, &t, yymsp[-1].minor.yy420);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2815 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 67: /* cmd ::= DROP VIEW ifexists fullname */
#line 438 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy147, &t, yymsp[-1].minor.yy420);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2825 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 70: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 452 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy442, yymsp[0].minor.yy491, yymsp[-4].minor.yy420);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy491);
  }
}
#line 2838 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 71: /* cmd ::= select */
#line 464 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy491, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy491);
  sql_select_delete(pParse->db, yymsp[0].minor.yy491);
}
#line 2850 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 72: /* select ::= with selectnowith */
#line 507 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy491;
  if( p ){
    p->pWith = yymsp[-1].minor.yy523;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy523);
  }
  yymsp[-1].minor.yy491 = p; /*A-overwrites-W*/
}
#line 2864 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 73: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 520 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy491;
  Select *pLhs = yymsp[-2].minor.yy491;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy420;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy420!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy491 = pRhs;
}
#line 2890 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 74: /* multiselect_op ::= UNION */
      case 76: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==76);
#line 543 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2896 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 75: /* multiselect_op ::= UNION ALL */
#line 544 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy420 = TK_ALL;}
#line 2901 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 77: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 548 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  yymsp[-8].minor.yy491 = sqlSelectNew(pParse,yymsp[-6].minor.yy442,yymsp[-5].minor.yy147,yymsp[-4].minor.yy130,yymsp[-3].minor.yy442,yymsp[-2].minor.yy130,yymsp[-1].minor.yy442,yymsp[-7].minor.yy420,yymsp[0].minor.yy132.pLimit,yymsp[0].minor.yy132.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy491!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy491->zSelName), yymsp[-8].minor.yy491->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy491->zSelName), yymsp[-8].minor.yy491->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2935 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 78: /* values ::= VALUES LP nexprlist RP */
#line 582 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy491 = sqlSelectNew(pParse,yymsp[-1].minor.yy442,0,0,0,0,0,SF_Values,0,0);
}
#line 2942 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 79: /* values ::= values COMMA LP exprlist RP */
#line 585 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy491;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy442,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy491 = pRight;
  }else{
    yymsp[-4].minor.yy491 = pLeft;
  }
}
#line 2958 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 80: /* distinct ::= DISTINCT */
#line 602 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = SF_Distinct;}
#line 2963 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 81: /* distinct ::= ALL */
#line 603 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = SF_All;}
#line 2968 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 83: /* sclp ::= */
      case 109: /* orderby_opt ::= */ yytestcase(yyruleno==109);
      case 120: /* groupby_opt ::= */ yytestcase(yyruleno==120);
      case 217: /* exprlist ::= */ yytestcase(yyruleno==217);
      case 220: /* paren_exprlist ::= */ yytestcase(yyruleno==220);
      case 225: /* eidlist_opt ::= */ yytestcase(yyruleno==225);
#line 616 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy442 = 0;}
#line 2978 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 84: /* selcollist ::= sclp expr as */
#line 617 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy442 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy442, yymsp[-1].minor.yy358.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy442, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy442,&yymsp[-1].minor.yy358);
}
#line 2987 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 85: /* selcollist ::= sclp STAR */
#line 622 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy442 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy442, p);
}
#line 2999 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 86: /* selcollist ::= sclp nm DOT STAR */
#line 630 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy442 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy442, pDot);
}
#line 3013 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 87: /* as ::= AS nm */
#line 645 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 3018 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 88: /* as ::= */
#line 647 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 3023 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 89: /* from ::= */
#line 659 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy147 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy147));}
#line 3028 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 90: /* from ::= FROM seltablist */
#line 660 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy147 = yymsp[0].minor.yy147;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy147);
}
#line 3036 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 91: /* stl_prefix ::= seltablist joinop */
#line 668 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy147 && yymsp[-1].minor.yy147->nSrc>0) ) yymsp[-1].minor.yy147->a[yymsp[-1].minor.yy147->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy420;
}
#line 3043 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 92: /* stl_prefix ::= */
#line 671 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy147 = 0;}
#line 3048 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 673 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy147 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy147,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy130,yymsp[0].minor.yy200);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy147, &yymsp[-2].minor.yy0);
}
#line 3056 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 678 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy147 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy147,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy130,yymsp[0].minor.yy200);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy147, yymsp[-4].minor.yy442);
}
#line 3064 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 683 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy147 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy147,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy491,yymsp[-1].minor.yy130,yymsp[0].minor.yy200);
}
#line 3071 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 687 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy147==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy130==0 && yymsp[0].minor.yy200==0 ){
    yymsp[-6].minor.yy147 = yymsp[-4].minor.yy147;
  }else if( yymsp[-4].minor.yy147->nSrc==1 ){
    yymsp[-6].minor.yy147 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy147,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy130,yymsp[0].minor.yy200);
    if( yymsp[-6].minor.yy147 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy147->a[yymsp[-6].minor.yy147->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy147->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy147);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy147);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy147,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy147 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy147,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy130,yymsp[0].minor.yy200);
  }
}
#line 3096 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 97: /* fullname ::= nm */
#line 711 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  /* yylhsminor.yy147-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy147 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy147 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3108 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy147 = yylhsminor.yy147;
        break;
      case 98: /* joinop ::= COMMA|JOIN */
#line 724 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy420 = JT_INNER; }
#line 3114 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW JOIN */
#line 726 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy420 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3119 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW join_nm JOIN */
#line 728 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy420 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3124 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 730 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-3].minor.yy420 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3129 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 102: /* on_opt ::= ON expr */
      case 123: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==131);
      case 215: /* case_else ::= ELSE expr */ yytestcase(yyruleno==215);
#line 734 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy130 = yymsp[0].minor.yy358.pExpr;}
#line 3137 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 103: /* on_opt ::= */
      case 122: /* having_opt ::= */ yytestcase(yyruleno==122);
      case 130: /* where_opt ::= */ yytestcase(yyruleno==130);
      case 216: /* case_else ::= */ yytestcase(yyruleno==216);
#line 735 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy130 = 0;}
#line 3145 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 104: /* indexed_opt ::= */
#line 748 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3150 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 105: /* indexed_opt ::= INDEXED BY nm */
#line 749 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3155 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 106: /* indexed_opt ::= NOT INDEXED */
#line 750 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3160 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 107: /* using_opt ::= USING LP idlist RP */
#line 754 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-3].minor.yy200 = yymsp[-1].minor.yy200;}
#line 3165 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 108: /* using_opt ::= */
      case 141: /* idlist_opt ::= */ yytestcase(yyruleno==141);
#line 755 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy200 = 0;}
#line 3171 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 110: /* orderby_opt ::= ORDER BY sortlist */
      case 121: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==121);
#line 769 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy442 = yymsp[0].minor.yy442;}
#line 3177 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 111: /* sortlist ::= sortlist COMMA expr sortorder */
#line 770 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy442 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy442,yymsp[-1].minor.yy358.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy442,yymsp[0].minor.yy420);
}
#line 3185 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 112: /* sortlist ::= expr sortorder */
#line 774 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  /* yylhsminor.yy442-overwrites-yymsp[-1].minor.yy358. */
  yylhsminor.yy442 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy358.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy442,yymsp[0].minor.yy420);
}
#line 3194 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-1].minor.yy442 = yylhsminor.yy442;
        break;
      case 113: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 788 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy420 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy358.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy442 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy442, yymsp[-1].minor.yy358.pExpr);
}
#line 3209 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 114: /* col_list_with_autoinc ::= expr autoinc */
#line 799 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy420 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy358.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy442-overwrites-yymsp[-1].minor.yy358. */
  yylhsminor.yy442 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy358.pExpr);
}
#line 3224 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-1].minor.yy442 = yylhsminor.yy442;
        break;
      case 115: /* enable ::= ENABLE */
#line 812 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy9 = true;}
#line 3230 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 116: /* enable ::= DISABLE */
#line 813 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy9 = false;}
#line 3235 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 117: /* sortorder ::= ASC */
#line 817 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = SORT_ORDER_ASC;}
#line 3240 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 118: /* sortorder ::= DESC */
#line 818 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = SORT_ORDER_DESC;}
#line 3245 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 119: /* sortorder ::= */
#line 819 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy420 = SORT_ORDER_UNDEF;}
#line 3250 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 124: /* limit_opt ::= */
#line 844 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy132.pLimit = 0; yymsp[1].minor.yy132.pOffset = 0;}
#line 3255 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 125: /* limit_opt ::= LIMIT expr */
#line 845 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy132.pLimit = yymsp[0].minor.yy358.pExpr; yymsp[-1].minor.yy132.pOffset = 0;}
#line 3260 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 847 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-3].minor.yy132.pLimit = yymsp[-2].minor.yy358.pExpr; yymsp[-3].minor.yy132.pOffset = yymsp[0].minor.yy358.pExpr;}
#line 3265 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr COMMA expr */
#line 849 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-3].minor.yy132.pOffset = yymsp[-2].minor.yy358.pExpr; yymsp[-3].minor.yy132.pLimit = yymsp[0].minor.yy358.pExpr;}
#line 3270 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 128: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 853 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy523, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy147, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy147,yymsp[0].minor.yy130);
}
#line 3282 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 129: /* cmd ::= TRUNCATE TABLE fullname */
#line 864 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy147);
}
#line 3290 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 132: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 878 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy523, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy147, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy442 != NULL && yymsp[-1].minor.yy442->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy442->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy147,yymsp[-1].minor.yy442,yymsp[0].minor.yy130,yymsp[-5].minor.yy420);
}
#line 3307 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 133: /* setlist ::= setlist COMMA nm EQ expr */
#line 895 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy442 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy442, yymsp[0].minor.yy358.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy442, &yymsp[-2].minor.yy0, 1);
}
#line 3315 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 899 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy442 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy442, yymsp[-3].minor.yy200, yymsp[0].minor.yy358.pExpr);
}
#line 3322 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 135: /* setlist ::= nm EQ expr */
#line 902 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy442 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy358.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy442, &yymsp[-2].minor.yy0, 1);
}
#line 3330 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-2].minor.yy442 = yylhsminor.yy442;
        break;
      case 136: /* setlist ::= LP idlist RP EQ expr */
#line 906 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy442 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy200, yymsp[0].minor.yy358.pExpr);
}
#line 3338 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 137: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 912 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy523, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy147, yymsp[0].minor.yy491, yymsp[-1].minor.yy200, yymsp[-4].minor.yy420);
}
#line 3349 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 920 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy523, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy147, 0, yymsp[-2].minor.yy200, yymsp[-5].minor.yy420);
}
#line 3360 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 142: /* idlist_opt ::= LP idlist RP */
#line 938 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy200 = yymsp[-1].minor.yy200;}
#line 3365 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 143: /* idlist ::= idlist COMMA nm */
#line 939 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy200 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy200,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy200 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3376 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 144: /* idlist ::= nm */
#line 946 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  /* yylhsminor.yy200-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy200 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy200 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3388 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy200 = yylhsminor.yy200;
        break;
      case 145: /* expr ::= LP expr RP */
#line 1036 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy358,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy358.pExpr = yymsp[-1].minor.yy358.pExpr;}
#line 3394 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 146: /* term ::= NULL */
      case 150: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==150);
      case 151: /* term ::= STRING */ yytestcase(yyruleno==151);
      case 152: /* term ::= FALSE */ yytestcase(yyruleno==152);
      case 153: /* term ::= TRUE */ yytestcase(yyruleno==153);
      case 154: /* term ::= UNKNOWN */ yytestcase(yyruleno==154);
      case 155: /* term ::= DECIMAL */ yytestcase(yyruleno==155);
#line 1037 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy358,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3405 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 147: /* expr ::= ID|INDEXED */
      case 148: /* expr ::= JOIN_KW */ yytestcase(yyruleno==148);
#line 1038 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy358,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3411 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 149: /* expr ::= nm DOT nm */
#line 1040 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy358,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy358.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3430 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 156: /* term ::= INTEGER */
#line 1062 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy358.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy358.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy358.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy358.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy358.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy358.pExpr ) yylhsminor.yy358.pExpr->flags |= EP_Leaf;
}
#line 3445 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy358 = yylhsminor.yy358;
        break;
      case 157: /* expr ::= VARNUM */
#line 1073 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy358.pExpr = expr_new_variable(pParse, &yymsp[0].minor.yy0, NULL);
  spanSet(&yylhsminor.yy358, &yymsp[0].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3454 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy358 = yylhsminor.yy358;
        break;
      case 158: /* expr ::= COLON|VARIABLE ID|INDEXED */
      case 159: /* expr ::= COLON|VARIABLE INTEGER */ yytestcase(yyruleno==159);
#line 1077 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy358.pExpr = expr_new_variable(pParse, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);
  spanSet(&yylhsminor.yy358, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3464 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-1].minor.yy358 = yylhsminor.yy358;
        break;
      case 160: /* expr ::= expr COLLATE ID|INDEXED */
#line 1085 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy358.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy358.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy358.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3473 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 161: /* expr ::= CAST LP expr AS typedef RP */
#line 1090 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy358,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy358.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy358.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy358.pExpr->type = yymsp[-1].minor.yy194.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy358.pExpr, yymsp[-3].minor.yy358.pExpr, 0);
}
#line 3487 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 162: /* expr ::= expr LB getlist RB */
#line 1101 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Expr *expr = sql_expr_new_anon(pParse->db, TK_GETITEM);
  if (expr == NULL) {
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy142);
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy142, yymsp[-3].minor.yy358.pExpr);
  expr->x.pList = yymsp[-1].minor.yy142;
  expr->type = FIELD_TYPE_ANY;
  sqlExprSetHeightAndFlags(pParse, expr);
  yylhsminor.yy358.pExpr = expr;
  yylhsminor.yy358.zStart = yymsp[-3].minor.yy358.zStart;
  yylhsminor.yy358.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3506 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-3].minor.yy358 = yylhsminor.yy358;
        break;
      case 163: /* getlist ::= getlist RB LB expr */
#line 1117 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy142, yymsp[0].minor.yy358.pExpr);
}
#line 3514 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 164: /* getlist ::= expr */
#line 1120 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy142 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy358.pExpr);
}
#line 3521 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy142 = yylhsminor.yy142;
        break;
      case 165: /* expr ::= LB exprlist RB */
#line 1127 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Expr *expr = sql_expr_new_anon(pParse->db, TK_ARRAY);
  if (expr == NULL) {
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy442);
    pParse->is_aborted = true;
    return;
  }
  expr->x.pList = yymsp[-1].minor.yy442;
  expr->type = FIELD_TYPE_ARRAY;
  sqlExprSetHeightAndFlags(pParse, expr);
  yylhsminor.yy358.pExpr = expr;
  spanSet(&yylhsminor.yy358, &yymsp[-2].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3539 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-2].minor.yy358 = yylhsminor.yy358;
        break;
      case 166: /* expr ::= LCB maplist RCB */
#line 1141 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct sql *db = pParse->db;
  struct Expr *expr = sql_expr_new_anon(db, TK_MAP);
  if (expr == NULL) {
    sql_expr_list_delete(db, yymsp[-1].minor.yy142);
    pParse->is_aborted = true;
    return;
  }
  expr->x.pList = yymsp[-1].minor.yy142;
  expr->type = FIELD_TYPE_MAP;
  sqlExprSetHeightAndFlags(pParse, expr);
  yylhsminor.yy358.pExpr = expr;
  spanSet(&yylhsminor.yy358, &yymsp[-2].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3558 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-2].minor.yy358 = yylhsminor.yy358;
        break;
      case 167: /* maplist ::= */
#line 1157 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[1].minor.yy142 = NULL;
}
#line 3566 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 168: /* nmaplist ::= nmaplist COMMA expr COLON expr */
#line 1160 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy142, yymsp[-2].minor.yy358.pExpr);
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy142, yymsp[0].minor.yy358.pExpr);
}
#line 3574 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 169: /* nmaplist ::= expr COLON expr */
#line 1164 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy142 = sql_expr_list_append(pParse->db, NULL, yymsp[-2].minor.yy358.pExpr);
  yylhsminor.yy142 = sql_expr_list_append(pParse->db, yylhsminor.yy142, yymsp[0].minor.yy358.pExpr);
}
#line 3582 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-2].minor.yy142 = yylhsminor.yy142;
        break;
      case 170: /* expr ::= TRIM LP trim_operands RP */
#line 1174 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy358.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy359, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy358, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3591 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-3].minor.yy358 = yylhsminor.yy358;
        break;
      case 171: /* trim_operands ::= trim_specification expr FROM expr */
#line 1182 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy358.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-3].minor.yy157]);
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, yylhsminor.yy359, p);
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, yylhsminor.yy359, yymsp[-2].minor.yy358.pExpr);
}
#line 3603 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-3].minor.yy359 = yylhsminor.yy359;
        break;
      case 172: /* trim_operands ::= trim_specification FROM expr */
#line 1190 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy358.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy157]);
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, yylhsminor.yy359, p);
}
#line 3614 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-2].minor.yy359 = yylhsminor.yy359;
        break;
      case 173: /* trim_operands ::= expr FROM expr */
#line 1197 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy358.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[TRIM_BOTH]);
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, yylhsminor.yy359, p);
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, yylhsminor.yy359, yymsp[-2].minor.yy358.pExpr);
}
#line 3626 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-2].minor.yy359 = yylhsminor.yy359;
        break;
      case 174: /* trim_operands ::= expr */
#line 1205 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy358.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[TRIM_BOTH]);
  yylhsminor.yy359 = sql_expr_list_append(pParse->db, yylhsminor.yy359, p);
}
#line 3637 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy359 = yylhsminor.yy359;
        break;
      case 175: /* expr_optional ::= */
#line 1215 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[1].minor.yy71 = NULL; }
#line 3643 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 176: /* expr_optional ::= expr */
#line 1216 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yylhsminor.yy71 = yymsp[0].minor.yy358.pExpr; }
#line 3648 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy71 = yylhsminor.yy71;
        break;
      case 177: /* trim_specification ::= LEADING */
#line 1220 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy157 = TRIM_LEADING; }
#line 3654 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 178: /* trim_specification ::= TRAILING */
#line 1221 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy157 = TRIM_TRAILING; }
#line 3659 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 179: /* trim_specification ::= BOTH */
#line 1222 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy157 = TRIM_BOTH; }
#line 3664 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 180: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 181: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==181);
#line 1224 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy442 && yymsp[-1].minor.yy442->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy442->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy358.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy442, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy358,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy420==SF_Distinct && yylhsminor.yy358.pExpr ){
    yylhsminor.yy358.pExpr->flags |= EP_Distinct;
  }
}
#line 3683 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-4].minor.yy358 = yylhsminor.yy358;
        break;
      case 182: /* expr ::= ID|INDEXED LP STAR RP */
#line 1259 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy358.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy358,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3692 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-3].minor.yy358 = yylhsminor.yy358;
        break;
      case 183: /* expr ::= LP nexprlist COMMA expr RP */
#line 1294 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy442, yymsp[-1].minor.yy358.pExpr);
  yylhsminor.yy358.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy358.pExpr ){
    yylhsminor.yy358.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy358, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3707 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-4].minor.yy358 = yylhsminor.yy358;
        break;
      case 184: /* expr ::= expr AND expr */
      case 185: /* expr ::= expr OR expr */ yytestcase(yyruleno==185);
      case 186: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==186);
      case 187: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==187);
      case 188: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==188);
      case 189: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==189);
      case 190: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==190);
      case 191: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==191);
#line 1305 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy358,&yymsp[0].minor.yy358);}
#line 3720 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 192: /* likeop ::= LIKE_KW|MATCH */
#line 1318 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3725 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 193: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1319 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3730 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 194: /* expr ::= expr likeop expr */
#line 1320 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy358.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy358.pExpr);
  yymsp[-2].minor.yy358.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy358);
  yymsp[-2].minor.yy358.zEnd = yymsp[0].minor.yy358.zEnd;
  if( yymsp[-2].minor.yy358.pExpr ) yymsp[-2].minor.yy358.pExpr->flags |= EP_InfixFunc;
}
#line 3745 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 195: /* expr ::= expr likeop expr ESCAPE expr */
#line 1331 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy358.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy358.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy358.pExpr);
  yymsp[-4].minor.yy358.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy358);
  yymsp[-4].minor.yy358.zEnd = yymsp[0].minor.yy358.zEnd;
  if( yymsp[-4].minor.yy358.pExpr ) yymsp[-4].minor.yy358.pExpr->flags |= EP_InfixFunc;
}
#line 3761 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 196: /* expr ::= expr IS NULL */
#line 1361 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy358,&yymsp[0].minor.yy0);}
#line 3766 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 197: /* expr ::= expr IS NOT NULL */
#line 1362 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy358,&yymsp[0].minor.yy0);}
#line 3771 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 198: /* expr ::= NOT expr */
      case 199: /* expr ::= BITNOT expr */ yytestcase(yyruleno==199);
#line 1384 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy358,pParse,yymsp[-1].major,&yymsp[0].minor.yy358,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3777 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 200: /* expr ::= MINUS expr */
#line 1388 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy358,pParse,TK_UMINUS,&yymsp[0].minor.yy358,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3782 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 201: /* expr ::= PLUS expr */
#line 1390 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy358,pParse,TK_UPLUS,&yymsp[0].minor.yy358,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3787 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 202: /* between_op ::= BETWEEN */
      case 205: /* in_op ::= IN */ yytestcase(yyruleno==205);
#line 1393 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = 0;}
#line 3793 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 204: /* expr ::= expr between_op expr AND expr */
#line 1395 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy358.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy358.pExpr);
  yymsp[-4].minor.yy358.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy358.pExpr, 0);
  if( yymsp[-4].minor.yy358.pExpr ){
    yymsp[-4].minor.yy358.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy420, &yymsp[-4].minor.yy358);
  yymsp[-4].minor.yy358.zEnd = yymsp[0].minor.yy358.zEnd;
}
#line 3809 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 207: /* expr ::= expr in_op LP exprlist RP */
#line 1410 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy442==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy358.pExpr);
    int tk = yymsp[-3].minor.yy420 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy358.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy358.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy358.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy442->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy442->a[0].pExpr;
    yymsp[-1].minor.yy442->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy442);
    yymsp[-4].minor.yy358.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy420 ? TK_NE : TK_EQ, yymsp[-4].minor.yy358.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy358.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy358.pExpr, 0);
    if( yymsp[-4].minor.yy358.pExpr ){
      yymsp[-4].minor.yy358.pExpr->x.pList = yymsp[-1].minor.yy442;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy358.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy442);
    }
    exprNot(pParse, yymsp[-3].minor.yy420, &yymsp[-4].minor.yy358);
  }
  yymsp[-4].minor.yy358.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3859 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 208: /* expr ::= LP select RP */
#line 1456 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy358,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy358.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy358.pExpr, yymsp[-1].minor.yy491);
}
#line 3868 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 209: /* expr ::= expr in_op LP select RP */
#line 1461 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy358.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy358.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy358.pExpr, yymsp[-1].minor.yy491);
  exprNot(pParse, yymsp[-3].minor.yy420, &yymsp[-4].minor.yy358);
  yymsp[-4].minor.yy358.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3878 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 210: /* expr ::= expr in_op nm paren_exprlist */
#line 1467 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy442 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy442);
  yymsp[-3].minor.yy358.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy358.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy358.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy420, &yymsp[-3].minor.yy358);
  yymsp[-3].minor.yy358.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3895 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 211: /* expr ::= EXISTS LP select RP */
#line 1480 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy358,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy358.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy491);
}
#line 3905 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 212: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1488 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy358,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy358.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy71, 0);
  if( yymsp[-4].minor.yy358.pExpr ){
    yymsp[-4].minor.yy358.pExpr->x.pList = yymsp[-1].minor.yy130 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy442,yymsp[-1].minor.yy130) : yymsp[-2].minor.yy442;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy358.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy442);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy130);
  }
}
#line 3920 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 213: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1501 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy442 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy442, yymsp[-2].minor.yy358.pExpr);
  yymsp[-4].minor.yy442 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy442, yymsp[0].minor.yy358.pExpr);
}
#line 3928 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 214: /* case_exprlist ::= WHEN expr THEN expr */
#line 1505 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy442 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy358.pExpr);
  yymsp[-3].minor.yy442 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy442, yymsp[0].minor.yy358.pExpr);
}
#line 3936 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 218: /* nexprlist ::= nexprlist COMMA expr */
#line 1522 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy442 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy442,yymsp[0].minor.yy358.pExpr);}
#line 3941 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 219: /* nexprlist ::= expr */
#line 1524 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy442 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy358.pExpr); /*A-overwrites-Y*/}
#line 3946 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 221: /* paren_exprlist ::= LP exprlist RP */
      case 226: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==226);
#line 1531 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy442 = yymsp[-1].minor.yy442;}
#line 3952 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 222: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1537 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy442, yymsp[-8].minor.yy420,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy420);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3967 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 223: /* uniqueflag ::= UNIQUE */
#line 1550 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = SQL_INDEX_TYPE_UNIQUE;}
#line 3972 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 224: /* uniqueflag ::= */
#line 1551 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy420 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3977 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 227: /* eidlist ::= eidlist COMMA nm */
#line 1586 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy442 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy442, &yymsp[0].minor.yy0);
}
#line 3984 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 228: /* eidlist ::= nm */
#line 1589 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[0].minor.yy442 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3991 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 229: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1596 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy147, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy420);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 4000 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 230: /* cmd ::= SET SESSION nm EQ term */
#line 1604 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    sql_setting_set(pParse,&yymsp[-2].minor.yy0,yymsp[0].minor.yy358.pExpr);
}
#line 4007 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 231: /* cmd ::= PRAGMA nm */
#line 1610 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 4014 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 232: /* cmd ::= PRAGMA nm LP nm RP */
#line 1613 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 4021 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 233: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1616 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 4028 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 234: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1621 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy524, &all);
}
#line 4039 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 235: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1631 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy147, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy420, yymsp[-4].minor.yy498.a, yymsp[-4].minor.yy498.b, yymsp[0].minor.yy130,
                          yymsp[-7].minor.yy420);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 4049 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 236: /* trigger_time ::= BEFORE */
#line 1639 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy420 = TK_BEFORE; }
#line 4054 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 237: /* trigger_time ::= AFTER */
#line 1640 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy420 = TK_AFTER;  }
#line 4059 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 238: /* trigger_time ::= INSTEAD OF */
#line 1641 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = TK_INSTEAD;}
#line 4064 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 239: /* trigger_time ::= */
#line 1642 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[1].minor.yy420 = TK_BEFORE; }
#line 4069 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 240: /* trigger_event ::= DELETE|INSERT */
      case 241: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==241);
#line 1646 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy498.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy498.b = 0;}
#line 4075 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 242: /* trigger_event ::= UPDATE OF idlist */
#line 1648 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[-2].minor.yy498.a = TK_UPDATE; yymsp[-2].minor.yy498.b = yymsp[0].minor.yy200;}
#line 4080 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 243: /* foreach_clause ::= */
#line 1650 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 4090 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 244: /* when_clause ::= */
#line 1660 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[1].minor.yy130 = 0; }
#line 4095 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 245: /* when_clause ::= WHEN expr */
#line 1661 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy130 = yymsp[0].minor.yy358.pExpr; }
#line 4100 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 246: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1665 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy524!=0 );
  yymsp[-2].minor.yy524->pLast->pNext = yymsp[-1].minor.yy524;
  yymsp[-2].minor.yy524->pLast = yymsp[-1].minor.yy524;
}
#line 4109 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 247: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1670 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy524!=0 );
  yymsp[-1].minor.yy524->pLast = yymsp[-1].minor.yy524;
}
#line 4117 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 248: /* trnm ::= nm DOT nm */
#line 1681 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 4128 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 249: /* tridxby ::= INDEXED BY nm */
#line 1694 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 4138 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 250: /* tridxby ::= NOT INDEXED */
#line 1700 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 4148 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 251: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1713 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy524 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy442, yymsp[0].minor.yy130, yymsp[-5].minor.yy420);
     if (yymsp[-6].minor.yy524 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 4159 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 252: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1722 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  /*yylhsminor.yy524-overwrites-yymsp[-4].minor.yy420. */
  yylhsminor.yy524 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy200, yymsp[0].minor.yy491, yymsp[-4].minor.yy420);
  if (yylhsminor.yy524 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4171 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-4].minor.yy524 = yylhsminor.yy524;
        break;
      case 253: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1732 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy524 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy130);
  if (yymsp[-4].minor.yy524 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4183 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 254: /* trigger_cmd ::= select */
#line 1741 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  /* yylhsminor.yy524-overwrites-yymsp[0].minor.yy491. */
  yylhsminor.yy524 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy491);
  if (yylhsminor.yy524 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4195 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy524 = yylhsminor.yy524;
        break;
      case 255: /* expr ::= RAISE LP IGNORE RP */
#line 1751 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy358,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy358.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy358.pExpr ){
    yymsp[-3].minor.yy358.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 4207 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 256: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1758 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy358,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy358.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy358.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy358.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy420;
}
#line 4220 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 257: /* raisetype ::= ROLLBACK */
#line 1769 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4225 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 258: /* raisetype ::= ABORT */
#line 1770 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = ON_CONFLICT_ACTION_ABORT;}
#line 4230 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 259: /* raisetype ::= FAIL */
#line 1771 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[0].minor.yy420 = ON_CONFLICT_ACTION_FAIL;}
#line 4235 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 260: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1775 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy147, &t, yymsp[-1].minor.yy420);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4245 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 261: /* alter_table_start ::= ALTER TABLE fullname */
#line 1792 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-2].minor.yy176 = yymsp[0].minor.yy147; }
#line 4250 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 262: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1795 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
   yylhsminor.yy242.table_name = yymsp[-3].minor.yy176;
   yylhsminor.yy242.name = yymsp[0].minor.yy0;
   pParse->initiateTTrans = true;
 }
#line 4259 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-3].minor.yy242 = yylhsminor.yy242;
        break;
      case 263: /* alter_add_column ::= alter_table_start ADD column_name */
#line 1802 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yylhsminor.yy242.table_name = yymsp[-2].minor.yy176;
  yylhsminor.yy242.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4269 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[-2].minor.yy242 = yylhsminor.yy242;
        break;
      case 264: /* column_name ::= COLUMN nm */
#line 1808 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4275 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 265: /* column_name ::= nm */
#line 1809 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yylhsminor.yy0 = yymsp[0].minor.yy0; }
#line 4280 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 266: /* alter_column_def ::= alter_add_column typedef */
#line 1813 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, yymsp[-1].minor.yy242.table_name, &yymsp[-1].minor.yy242.name, &yymsp[0].minor.yy194);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  sql_create_column_start(pParse);
}
#line 4291 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 267: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1821 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy242.table_name, &yymsp[-11].minor.yy242.name, yymsp[-7].minor.yy442, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy442,
                     yymsp[-2].minor.yy420, yymsp[-1].minor.yy420, yymsp[0].minor.yy420);
  sql_create_foreign_key(pParse);
}
#line 4300 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 268: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1827 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy242.table_name, &yymsp[-4].minor.yy242.name, &yymsp[-1].minor.yy358);
    sql_create_check_contraint(pParse);
}
#line 4308 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 269: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1832 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy242.table_name, &yymsp[-4].minor.yy242.name, yymsp[-1].minor.yy442, yymsp[-3].minor.yy420,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4317 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 270: /* unique_spec ::= UNIQUE */
#line 1839 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy420 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4322 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 271: /* unique_spec ::= PRIMARY KEY */
#line 1840 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy420 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4327 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 272: /* cmd ::= alter_table_start RENAME TO nm */
#line 1842 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy176, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4336 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 273: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1848 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  drop_constraint_def_init(&pParse->drop_constraint_def, yymsp[-3].minor.yy147, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_constraint(pParse);
}
#line 4345 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 274: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1854 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy176,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy9);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4354 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 275: /* with ::= */
#line 1866 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{yymsp[1].minor.yy523 = 0;}
#line 4359 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 276: /* with ::= WITH wqlist */
#line 1867 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-1].minor.yy523 = yymsp[0].minor.yy523; }
#line 4364 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 277: /* with ::= WITH RECURSIVE wqlist */
#line 1868 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[-2].minor.yy523 = yymsp[0].minor.yy523; }
#line 4369 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 278: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1870 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy523 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy442, yymsp[-1].minor.yy491); /*A-overwrites-X*/
}
#line 4376 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 279: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1873 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy523 = sqlWithAdd(pParse, yymsp[-7].minor.yy523, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy442, yymsp[-1].minor.yy491);
}
#line 4383 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 280: /* typedef ::= TEXT */
      case 281: /* typedef ::= STRING_KW */ yytestcase(yyruleno==281);
#line 1879 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_STRING; }
#line 4389 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 282: /* typedef ::= SCALAR */
#line 1881 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_SCALAR; }
#line 4394 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 283: /* typedef ::= BOOL */
      case 284: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==284);
#line 1883 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_BOOLEAN; }
#line 4400 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 285: /* typedef ::= VARBINARY */
#line 1885 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_VARBINARY; }
#line 4405 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 286: /* typedef ::= UUID */
#line 1886 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_UUID; }
#line 4410 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 287: /* typedef ::= ANY */
#line 1887 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_ANY; }
#line 4415 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 288: /* typedef ::= ARRAY */
#line 1888 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_ARRAY; }
#line 4420 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 289: /* typedef ::= MAP */
#line 1889 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_MAP; }
#line 4425 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 290: /* typedef ::= DATETIME */
#line 1890 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_DATETIME; }
#line 4430 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 291: /* typedef ::= INTERVAL */
#line 1891 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_INTERVAL; }
#line 4435 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 292: /* char_len ::= LP INTEGER RP */
#line 1903 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy420;
  (void) yymsp[-1].minor.yy0;
}
#line 4443 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 293: /* typedef ::= VARCHAR char_len */
#line 1909 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy194.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy420;
}
#line 4451 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 294: /* number_typedef ::= NUMBER */
#line 1916 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_NUMBER; }
#line 4456 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 295: /* number_typedef ::= DOUBLE */
#line 1917 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_DOUBLE; }
#line 4461 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 296: /* number_typedef ::= INT|INTEGER_KW */
#line 1918 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_INTEGER; }
#line 4466 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 297: /* number_typedef ::= UNSIGNED */
#line 1919 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_UNSIGNED; }
#line 4471 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      case 298: /* number_typedef ::= DECIMAL */
#line 1920 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"
{ yymsp[0].minor.yy194.type = FIELD_TYPE_DECIMAL; }
#line 4476 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
        break;
      default:
      /* (299) input ::= ecmd */ yytestcase(yyruleno==299);
      /* (300) explain ::= */ yytestcase(yyruleno==300);
      /* (301) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=301);
      /* (302) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==302);
      /* (303) savepoint_opt ::= */ yytestcase(yyruleno==303);
      /* (304) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==304);
      /* (305) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==305);
      /* (306) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==306);
      /* (307) with_opts ::= */ yytestcase(yyruleno==307);
      /* (308) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==308);
      /* (309) columnlist ::= columnlist COMMA column_def create_column_end */ yytestcase(yyruleno==309);
      /* (310) columnlist ::= column_def create_column_end */ yytestcase(yyruleno==310);
      /* (311) column_def ::= column_name_and_type carglist */ yytestcase(yyruleno==311);
      /* (312) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=312);
      /* (313) carglist ::= carglist ccons */ yytestcase(yyruleno==313);
      /* (314) carglist ::= */ yytestcase(yyruleno==314);
      /* (315) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=315);
      /* (316) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=316);
      /* (317) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=317);
      /* (318) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=318);
      /* (319) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=319);
      /* (320) oneselect ::= values */ yytestcase(yyruleno==320);
      /* (321) sclp ::= selcollist COMMA */ yytestcase(yyruleno==321);
      /* (322) as ::= ID|STRING */ yytestcase(yyruleno==322);
      /* (323) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==323);
      /* (324) join_nm ::= JOIN_KW */ yytestcase(yyruleno==324);
      /* (325) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=325);
      /* (326) maplist ::= nmaplist */ yytestcase(yyruleno==326);
      /* (327) type_func ::= CHAR */ yytestcase(yyruleno==327);
      /* (328) exprlist ::= nexprlist */ yytestcase(yyruleno==328);
      /* (329) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==329);
      /* (330) trnm ::= nm */ yytestcase(yyruleno==330);
      /* (331) tridxby ::= */ yytestcase(yyruleno==331);
      /* (332) cmd ::= alter_column_def carglist create_column_end */ yytestcase(yyruleno==332);
      /* (333) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=333);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4582 "/usr/src/RPM/BUILD/tarantool-2.10.3/src/box/sql/parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
